/* Driver template for the LEMON parser generator.
** Copyright 1991-1995 by D. Richard Hipp.
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
**
** You should have received a copy of the GNU Library General Public
** License along with this library; if not, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
** Modified 1997 to make it suitable for use with makeheaders.
*/
/* First off, code is include which follows the "include" declaration
** in the input file. */
#line 1 "./mate_grammar.lemon"


/* mate_grammar.lemon
* MATE's configuration language grammar 
*
* Copyright 2005, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
*
* $Id: mate_grammar.lemon 16784 2005-12-13 22:08:37Z lego $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "mate.h"
#include "mate_grammar.h"

#define DUMMY void*

typedef struct _extraction {
	gchar* as;
	header_field_info* hfi;
	struct _extraction* next;
	struct _extraction* last;
} extraction_t;

typedef struct _pdu_criteria_t {
	AVPL* criterium_avpl;
	avpl_match_mode criterium_match_mode;
	accept_mode_t criterium_accept_mode;
} pdu_criteria_t;

typedef struct _gop_options {
	gop_tree_mode_t pdu_tree_mode;
	gboolean drop_unassigned;
	gboolean show_times;
	float expiration;
	float idle_timeout;
	float lifetime;
	AVPL* start;
	AVPL* stop;
	AVPL* extras;
} gop_options_t;

typedef struct _gog_statements {
	float expiration;
	gop_tree_mode_t gop_tree_mode;
	GPtrArray* transform_list;
	AVPL* extras;
	LoAL* current_gogkeys;
} gog_statement_t;

typedef struct _transf_match_t {
    avpl_match_mode match_mode;
    AVPL* avpl;
} transf_match_t; 

typedef struct _transf_action_t {
    avpl_replace_mode replace_mode;
    AVPL* avpl;
} transf_action_t;

static void configuration_error(mate_config* mc, const gchar* fmt, ...) {
	static gchar error_buffer[256];
	const gchar* incl;
	gint i;
	mate_config_frame* current_frame;
	va_list list;
	
	va_start( list, fmt );
	g_vsnprintf(error_buffer,sizeof(error_buffer),fmt,list);
	va_end( list );

	i = (gint) mc->config_stack->len;
	
	while (i--) {

		if (i>0) {
			incl = "\n   included from: ";
		} else {
			incl = " ";
		}
		
		current_frame = g_ptr_array_index(mc->config_stack,(guint)i);
		
		g_string_sprintfa(mc->config_error,"%s%s at line %u",incl, current_frame->filename, current_frame->linenum);
	}
	
	g_string_sprintfa(mc->config_error,": %s\n",error_buffer);
	
	THROW(MateConfigError);

}

static AVPL_Transf* new_transform_elem(AVPL* match, AVPL* replace, avpl_match_mode match_mode, avpl_replace_mode replace_mode) {
	 AVPL_Transf* t = g_malloc(sizeof(AVPL_Transf));
	 
	 t->name = NULL;
	 t->match = match;
	 t->replace = replace;
	 t->match_mode = match_mode;
	 t->replace_mode = replace_mode;
	 
	 t->map = NULL;
	 t->next = NULL;
	 
	 return t;
}

static gchar* recolonize(mate_config* mc, gchar* s) {
	GString* str = g_string_new("");
	gchar** vec;
	gchar* r;
	guint i,v;
	gchar c;
	
	vec = g_strsplit(s,":",0);
	
	for (i = 0; vec[i]; i++) {
		g_strdown(vec[i]);
		
		v = 0;
		switch ( strlen(vec[i]) ) {
		 case 2:
		    c = vec[i][1];
			vec[i][1] = vec[i][0];
			vec[i][0] = c;
			if (vec[i][0] >= '0' && vec[i][0] <= '9') {
				v += (vec[i][1] - '0' )*16;
			} else {
				v += (vec[i][1] - 'a' + 10)*16;
			}
		 case 1:
			if (vec[i][0] >= '0' && vec[i][0] <= '9') {
				v += (vec[i][0] - '0' );
			} else {
				v += (vec[i][0] - 'a' + 10);
			}
		 case 0:
			break;
		  default:
			configuration_error(mc,"bad token %s",s);
		}
		
		g_string_sprintfa(str,":%.2X",v);					
	}
	
	g_strfreev(vec);
	
	g_string_erase(str,0,1);
	
	r = str->str;
	
	g_string_free(str,FALSE);

	return r;
}


#line 198 "mate_grammar.c"
#include <stdio.h>
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/*
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands.
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash
**                       table.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    MateParserTOKENTYPE     is the data type used for minor tokens given
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is MateParserTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.
**    MateParserARGDECL       is a declaration of a 3rd argument to the
**                       parser, or null if there is no extra argument.
**    MateParserKRARGDECL     A version of MateParserARGDECL for K&R C.
**    MateParserANSIARGDECL   A version of MateParserARGDECL for ANSI C.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
/*  */
#define YYCODETYPE unsigned char
#define YYNOCODE 138
#define YYACTIONTYPE int
#define MateParserTOKENTYPE  gchar* 
typedef union {
  MateParserTOKENTYPE yy0;
  gop_options_t* yy1;
  accept_mode_t yy8;
  GPtrArray* yy9;
  avpl_replace_mode yy13;
  AVPL* yy70;
  LoAL* yy77;
  transf_action_t* yy85;
  AVPL_Transf* yy145;
  transf_match_t* yy146;
  avpl_match_mode yy156;
  extraction_t* yy179;
  gboolean yy182;
  pdu_criteria_t* yy199;
  header_field_info* yy210;
  gchar* yy212;
  AVP* yy226;
  gog_statement_t* yy229;
  float yy255;
  gop_tree_mode_t yy256;
  int yy275;
} YYMINORTYPE;
#define YYSTACKDEPTH 100
#define MateParserARGDECL ,mc 
#define MateParserXARGDECL  mate_config* mc ;
#define MateParserANSIARGDECL , mate_config* mc 
#define YYNSTATE 282
#define YYNRULE 147
#define YYERRORSYMBOL 76
#define YYERRSYMDT yy275
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)
/* Next is the action table.  Each entry in this table contains
**
**  +  An integer which is the number representing the look-ahead
**     token
**
**  +  An integer indicating what action to take.  Number (N) between
**     0 and YYNSTATE-1 mean shift the look-ahead and go to state N.
**     Numbers between YYNSTATE and YYNSTATE+YYNRULE-1 mean reduce by
**     rule N-YYNSTATE.  Number YYNSTATE+YYNRULE means that a syntax
**     error has occurred.  Number YYNSTATE+YYNRULE+1 means the parser
**     accepts its input.
**
**  +  A pointer to the next entry with the same hash value.
**
** The action table is really a series of hash tables.  Each hash
** table contains a number of entries which is a power of two.  The
** "state" table (which follows) contains information about the starting
** point and size of each hash table.
*/
struct yyActionEntry {
  YYCODETYPE   lookahead;   /* The value of the look-ahead token */
  YYACTIONTYPE action;      /* Action to take for this look-ahead */
  struct yyActionEntry *next; /* Next look-ahead with the same hash, or NULL */
};
static struct yyActionEntry yyActionTable[] = {
/* State 0 */
  { 112, 430, 0                    }, /*            mate_config accept */
  {  73,   1, 0                    }, /*                  decls shift  1 */
/* State 1 */
  {   0, 282, 0                    }, /*                      $ reduce 0 */
  { 129,   6, 0                    }, /*         transform_decl shift  6 */
  {  82,   5, 0                    }, /*               gog_decl shift  5 */
  { 115,   3, 0                    }, /*               pdu_decl shift  3 */
  {   9,  11, 0                    }, /*               DEBUG_KW shift  11 */
  {  26, 212, &yyActionTable[   8] }, /*                 GOP_KW shift  212 */
  {  10,  40, 0                    }, /*             DEFAULT_KW shift  40 */
  {  71,   8, 0                    }, /*             debug_decl shift  8 */
  {  72,   2, 0                    }, /*                   decl shift  2 */
  {  25, 259, &yyActionTable[   6] }, /*                 GOG_KW shift  259 */
  {  74,   7, &yyActionTable[   7] }, /*          defaults_decl shift  7 */
  {  59, 115, 0                    }, /*           TRANSFORM_KW shift  115 */
  {  92,   4, &yyActionTable[  16] }, /*               gop_decl shift  4 */
  {  45, 159, 0                    }, /*                 PDU_KW shift  159 */
  {  12,   9, 0                    }, /*                DONE_KW shift  9 */
  {YYNOCODE,0,0}, /* Unused */
/* State 2 */
  {YYNOCODE,0,0}, /* Unused */
/* State 3 */
  {YYNOCODE,0,0}, /* Unused */
/* State 4 */
  {YYNOCODE,0,0}, /* Unused */
/* State 5 */
  {YYNOCODE,0,0}, /* Unused */
/* State 6 */
  {YYNOCODE,0,0}, /* Unused */
/* State 7 */
  {YYNOCODE,0,0}, /* Unused */
/* State 8 */
  {YYNOCODE,0,0}, /* Unused */
/* State 9 */
  {  52,  10, 0                    }, /*              SEMICOLON shift  10 */
/* State 10 */
  {YYNOCODE,0,0}, /* Unused */
/* State 11 */
  {  42,  12, 0                    }, /*             OPEN_BRACE shift  12 */
/* State 12 */
  {  20,  35, 0                    }, /*            FILENAME_KW shift  35 */
  {  69,  13, 0                    }, /*        dbgfile_default shift  13 */
/* State 13 */
  {  70,  14, 0                    }, /*       dbglevel_default shift  14 */
  {  33,  32, 0                    }, /*               LEVEL_KW shift  32 */
/* State 14 */
  { 114,  15, 0                    }, /*   pdu_dbglevel_default shift  15 */
  {  45,  28, 0                    }, /*                 PDU_KW shift  28 */
/* State 15 */
  {  26,  24, 0                    }, /*                 GOP_KW shift  24 */
  {  91,  16, 0                    }, /*   gop_dbglevel_default shift  16 */
/* State 16 */
  {   4, 303, 0                    }, /*            CLOSE_BRACE reduce 21 */
  {  81,  17, &yyActionTable[  38] }, /*   gog_dbglevel_default shift  17 */
  {  25,  20, 0                    }, /*                 GOG_KW shift  20 */
  {YYNOCODE,0,0}, /* Unused */
/* State 17 */
  {   4,  18, 0                    }, /*            CLOSE_BRACE shift  18 */
/* State 18 */
  {  52,  19, 0                    }, /*              SEMICOLON shift  19 */
/* State 19 */
  {YYNOCODE,0,0}, /* Unused */
/* State 20 */
  {  33,  21, 0                    }, /*               LEVEL_KW shift  21 */
/* State 21 */
  {  30,  22, 0                    }, /*                INTEGER shift  22 */
/* State 22 */
  {  52,  23, 0                    }, /*              SEMICOLON shift  23 */
/* State 23 */
  {   4, 302, 0                    }, /*            CLOSE_BRACE reduce 20 */
/* State 24 */
  {  33,  25, 0                    }, /*               LEVEL_KW shift  25 */
/* State 25 */
  {  30,  26, 0                    }, /*                INTEGER shift  26 */
/* State 26 */
  {  52,  27, 0                    }, /*              SEMICOLON shift  27 */
/* State 27 */
  {YYNOCODE,0,0}, /* Unused */
/* State 28 */
  {  33,  29, 0                    }, /*               LEVEL_KW shift  29 */
/* State 29 */
  {  30,  30, 0                    }, /*                INTEGER shift  30 */
/* State 30 */
  {  52,  31, 0                    }, /*              SEMICOLON shift  31 */
/* State 31 */
  {YYNOCODE,0,0}, /* Unused */
/* State 32 */
  {  30,  33, 0                    }, /*                INTEGER shift  33 */
/* State 33 */
  {  52,  34, 0                    }, /*              SEMICOLON shift  34 */
/* State 34 */
  {YYNOCODE,0,0}, /* Unused */
/* State 35 */
  {  38,  38, 0                    }, /*                   NAME shift  38 */
  {  49,  36, 0                    }, /*                 QUOTED shift  36 */
/* State 36 */
  {  52,  37, 0                    }, /*              SEMICOLON shift  37 */
/* State 37 */
  {YYNOCODE,0,0}, /* Unused */
/* State 38 */
  {  52,  39, 0                    }, /*              SEMICOLON shift  39 */
/* State 39 */
  {YYNOCODE,0,0}, /* Unused */
/* State 40 */
  {  42,  41, 0                    }, /*             OPEN_BRACE shift  41 */
/* State 41 */
  { 116,  42, 0                    }, /*           pdu_defaults shift  42 */
  {  45,  99, 0                    }, /*                 PDU_KW shift  99 */
/* State 42 */
  {  26,  72, 0                    }, /*                 GOP_KW shift  72 */
  {  93,  43, 0                    }, /*           gop_defaults shift  43 */
/* State 43 */
  {   4, 328, 0                    }, /*            CLOSE_BRACE reduce 46 */
  {  25,  47, 0                    }, /*                 GOG_KW shift  47 */
  {YYNOCODE,0,0}, /* Unused */
  {  83,  44, 0                    }, /*           gog_defaults shift  44 */
/* State 44 */
  {   4,  45, 0                    }, /*            CLOSE_BRACE shift  45 */
/* State 45 */
  {  52,  46, 0                    }, /*              SEMICOLON shift  46 */
/* State 46 */
  {YYNOCODE,0,0}, /* Unused */
/* State 47 */
  {  42,  48, 0                    }, /*             OPEN_BRACE shift  48 */
/* State 48 */
  {  84,  49, &yyActionTable[  78] }, /* gog_expiration_default shift  49 */
  {  16,  67, 0                    }, /*          EXPIRATION_KW shift  67 */
/* State 49 */
  { 106,  57, &yyActionTable[  80] }, /*  gop_tree_mode_default shift  57 */
  {  54,  50, 0                    }, /*           SHOW_TREE_KW shift  50 */
/* State 50 */
  {  22,  55, 0                    }, /*          FRAME_TREE_KW shift  55 */
  { 105,  51, 0                    }, /*          gop_tree_mode shift  51 */
  {YYNOCODE,0,0}, /* Unused */
  {   3,  56, 0                    }, /*          BASIC_TREE_KW shift  56 */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  {  46,  54, &yyActionTable[  81] }, /*            PDU_TREE_KW shift  54 */
  {  39,  53, 0                    }, /*             NO_TREE_KW shift  53 */
/* State 51 */
  {  52,  52, 0                    }, /*              SEMICOLON shift  52 */
/* State 52 */
  {YYNOCODE,0,0}, /* Unused */
/* State 53 */
  {  52, 386, 0                    }, /*              SEMICOLON reduce 104 */
/* State 54 */
  {  52, 387, 0                    }, /*              SEMICOLON reduce 105 */
/* State 55 */
  {  52, 388, 0                    }, /*              SEMICOLON reduce 106 */
/* State 56 */
  {  52, 389, 0                    }, /*              SEMICOLON reduce 107 */
/* State 57 */
  {   4, 332, 0                    }, /*            CLOSE_BRACE reduce 50 */
  {YYNOCODE,0,0}, /* Unused */
  {  86,  58, 0                    }, /*    gog_goptree_default shift  58 */
  {  27,  61, 0                    }, /*            GOP_TREE_KW shift  61 */
/* State 58 */
  {   4,  59, 0                    }, /*            CLOSE_BRACE shift  59 */
/* State 59 */
  {  52,  60, 0                    }, /*              SEMICOLON shift  60 */
/* State 60 */
  {   4, 327, 0                    }, /*            CLOSE_BRACE reduce 45 */
/* State 61 */
  {  40,  64, &yyActionTable[ 103] }, /*           NULL_TREE_KW shift  64 */
  {  24,  65, 0                    }, /*           FULL_TREE_KW shift  65 */
  {   3,  66, 0                    }, /*          BASIC_TREE_KW shift  66 */
  { 107,  62, &yyActionTable[ 104] }, /*          gop_tree_type shift  62 */
/* State 62 */
  {  52,  63, 0                    }, /*              SEMICOLON shift  63 */
/* State 63 */
  {   4, 331, 0                    }, /*            CLOSE_BRACE reduce 49 */
/* State 64 */
  {  52, 400, 0                    }, /*              SEMICOLON reduce 118 */
/* State 65 */
  {  52, 401, 0                    }, /*              SEMICOLON reduce 119 */
/* State 66 */
  {  52, 402, 0                    }, /*              SEMICOLON reduce 120 */
/* State 67 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125,  68, &yyActionTable[ 111] }, /*             time_value shift  68 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 68 */
  {  52,  69, 0                    }, /*              SEMICOLON shift  69 */
/* State 69 */
  {YYNOCODE,0,0}, /* Unused */
/* State 70 */
  {  52, 393, 0                    }, /*              SEMICOLON reduce 111 */
/* State 71 */
  {  52, 394, 0                    }, /*              SEMICOLON reduce 112 */
/* State 72 */
  {  42,  73, 0                    }, /*             OPEN_BRACE shift  73 */
/* State 73 */
  {  96,  74, &yyActionTable[ 121] }, /* gop_expiration_default shift  74 */
  {  16,  96, 0                    }, /*          EXPIRATION_KW shift  96 */
/* State 74 */
  {  98,  75, &yyActionTable[ 123] }, /* gop_idle_timeout_default shift  75 */
  {  28,  93, 0                    }, /*        IDLE_TIMEOUT_KW shift  93 */
/* State 75 */
  {  34,  90, 0                    }, /*            LIFETIME_KW shift  90 */
  {  99,  76, 0                    }, /*   gop_lifetime_default shift  76 */
/* State 76 */
  {  94,  77, &yyActionTable[ 127] }, /* gop_drop_unassigned_default shift  77 */
  {  14,  87, 0                    }, /*     DROP_UNASSIGNED_KW shift  87 */
/* State 77 */
  { 106,  78, &yyActionTable[ 129] }, /*  gop_tree_mode_default shift  78 */
  {  54,  50, 0                    }, /*           SHOW_TREE_KW shift  50 */
/* State 78 */
  {   4, 326, 0                    }, /*            CLOSE_BRACE reduce 44 */
  {  53,  82, 0                    }, /*          SHOW_TIMES_KW shift  82 */
  { 102,  79, 0                    }, /* gop_show_times_default shift  79 */
  {YYNOCODE,0,0}, /* Unused */
/* State 79 */
  {   4,  80, 0                    }, /*            CLOSE_BRACE shift  80 */
/* State 80 */
  {  52,  81, 0                    }, /*              SEMICOLON shift  81 */
/* State 81 */
  {YYNOCODE,0,0}, /* Unused */
/* State 82 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135,  83, &yyActionTable[ 137] }, /*             true_false shift  83 */
/* State 83 */
  {  52,  84, 0                    }, /*              SEMICOLON shift  84 */
/* State 84 */
  {   4, 325, 0                    }, /*            CLOSE_BRACE reduce 43 */
/* State 85 */
  {  52, 390, 0                    }, /*              SEMICOLON reduce 108 */
/* State 86 */
  {  52, 391, 0                    }, /*              SEMICOLON reduce 109 */
/* State 87 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135,  88, &yyActionTable[ 145] }, /*             true_false shift  88 */
/* State 88 */
  {  52,  89, 0                    }, /*              SEMICOLON shift  89 */
/* State 89 */
  {YYNOCODE,0,0}, /* Unused */
/* State 90 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125,  91, &yyActionTable[ 151] }, /*             time_value shift  91 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 91 */
  {  52,  92, 0                    }, /*              SEMICOLON shift  92 */
/* State 92 */
  {YYNOCODE,0,0}, /* Unused */
/* State 93 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125,  94, &yyActionTable[ 157] }, /*             time_value shift  94 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 94 */
  {  52,  95, 0                    }, /*              SEMICOLON shift  95 */
/* State 95 */
  {YYNOCODE,0,0}, /* Unused */
/* State 96 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125,  97, &yyActionTable[ 163] }, /*             time_value shift  97 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 97 */
  {  52,  98, 0                    }, /*              SEMICOLON shift  98 */
/* State 98 */
  {YYNOCODE,0,0}, /* Unused */
/* State 99 */
  {  42, 100, 0                    }, /*             OPEN_BRACE shift  100 */
/* State 100 */
  { 120, 101, 0                    }, /* pdu_last_extracted_default shift  101 */
  {  31, 112, 0                    }, /*      LAST_EXTRACTED_KW shift  112 */
/* State 101 */
  { 118, 102, &yyActionTable[ 173] }, /* pdu_drop_unassigned_default shift  102 */
  {  14, 109, 0                    }, /*     DROP_UNASSIGNED_KW shift  109 */
/* State 102 */
  {   4, 312, 0                    }, /*            CLOSE_BRACE reduce 30 */
  { 117, 103, 0                    }, /*    pdu_discard_default shift  103 */
  {YYNOCODE,0,0}, /* Unused */
  {  11, 106, 0                    }, /*    DISCARD_PDU_DATA_KW shift  106 */
/* State 103 */
  {   4, 104, 0                    }, /*            CLOSE_BRACE shift  104 */
/* State 104 */
  {  52, 105, 0                    }, /*              SEMICOLON shift  105 */
/* State 105 */
  {YYNOCODE,0,0}, /* Unused */
/* State 106 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 107, &yyActionTable[ 181] }, /*             true_false shift  107 */
/* State 107 */
  {  52, 108, 0                    }, /*              SEMICOLON shift  108 */
/* State 108 */
  {   4, 311, 0                    }, /*            CLOSE_BRACE reduce 29 */
/* State 109 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 110, &yyActionTable[ 187] }, /*             true_false shift  110 */
/* State 110 */
  {  52, 111, 0                    }, /*              SEMICOLON shift  111 */
/* State 111 */
  {YYNOCODE,0,0}, /* Unused */
/* State 112 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 113, &yyActionTable[ 193] }, /*             true_false shift  113 */
/* State 113 */
  {  52, 114, 0                    }, /*              SEMICOLON shift  114 */
/* State 114 */
  {YYNOCODE,0,0}, /* Unused */
/* State 115 */
  {  38, 116, 0                    }, /*                   NAME shift  116 */
/* State 116 */
  { 128, 117, &yyActionTable[ 201] }, /*         transform_body shift  117 */
  {  42, 119, 0                    }, /*             OPEN_BRACE shift  119 */
/* State 117 */
  {  52, 118, 0                    }, /*              SEMICOLON shift  118 */
/* State 118 */
  {YYNOCODE,0,0}, /* Unused */
/* State 119 */
  { 132, 123, &yyActionTable[ 207] }, /*        transform_match shift  123 */
  { 133, 158, 0                    }, /*    transform_statement shift  158 */
  { 134, 120, 0                    }, /*   transform_statements shift  120 */
  {  36, 152, 0                    }, /*               MATCH_KW shift  152 */
/* State 120 */
  { 132, 123, &yyActionTable[ 210] }, /*        transform_match shift  123 */
  { 133, 122, 0                    }, /*    transform_statement shift  122 */
  {  36, 152, &yyActionTable[ 211] }, /*               MATCH_KW shift  152 */
  {   4, 121, 0                    }, /*            CLOSE_BRACE shift  121 */
/* State 121 */
  {  52, 334, 0                    }, /*              SEMICOLON reduce 52 */
/* State 122 */
  {YYNOCODE,0,0}, /* Unused */
/* State 123 */
  {  43, 348, 0                    }, /*            OPEN_PARENS reduce 66 */
  {  63, 126, 0                    }, /*            action_mode shift  126 */
  {YYNOCODE,0,0}, /* Unused */
  {  51, 150, &yyActionTable[ 214] }, /*             REPLACE_KW shift  150 */
  {  52, 340, 0                    }, /*              SEMICOLON reduce 58 */
  {  29, 151, 0                    }, /*              INSERT_KW shift  151 */
  {YYNOCODE,0,0}, /* Unused */
  { 127, 124, &yyActionTable[ 215] }, /*       transform_action shift  124 */
/* State 124 */
  {  52, 125, 0                    }, /*              SEMICOLON shift  125 */
/* State 125 */
  {YYNOCODE,0,0}, /* Unused */
/* State 126 */
  {  66, 127, 0                    }, /*                   avpl shift  127 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 127 */
  {  52, 341, 0                    }, /*              SEMICOLON reduce 59 */
/* State 128 */
  {  64, 149, 0                    }, /*                    avp shift  149 */
  {   5, 148, 0                    }, /*           CLOSE_PARENS shift  148 */
  {  38, 133, 0                    }, /*                   NAME shift  133 */
  {  67, 129, 0                    }, /*                   avps shift  129 */
/* State 129 */
  {   5, 130, 0                    }, /*           CLOSE_PARENS shift  130 */
  {   7, 131, &yyActionTable[ 231] }, /*                  COMMA shift  131 */
/* State 130 */
  {YYNOCODE,0,0}, /* Unused */
/* State 131 */
  {  64, 132, &yyActionTable[ 235] }, /*                    avp shift  132 */
  {  38, 133, 0                    }, /*                   NAME shift  133 */
/* State 132 */
  {YYNOCODE,0,0}, /* Unused */
/* State 133 */
  {  42, 142, &yyActionTable[ 238] }, /*             OPEN_BRACE shift  142 */
  {   2, 134, 0                    }, /*           AVP_OPERATOR shift  134 */
/* State 134 */
  { 136, 135, 0                    }, /*                  value shift  135 */
  {  49, 136, 0                    }, /*                 QUOTED shift  136 */
  {  13, 140, 0                    }, /*               DOTED_IP shift  140 */
  {  30, 139, &yyActionTable[ 243] }, /*                INTEGER shift  139 */
  {   6, 141, 0                    }, /*              COLONIZED shift  141 */
  {  21, 138, &yyActionTable[ 241] }, /*               FLOATING shift  138 */
  {  38, 137, &yyActionTable[ 242] }, /*                   NAME shift  137 */
  {YYNOCODE,0,0}, /* Unused */
/* State 135 */
  {YYNOCODE,0,0}, /* Unused */
/* State 136 */
  {YYNOCODE,0,0}, /* Unused */
/* State 137 */
  {YYNOCODE,0,0}, /* Unused */
/* State 138 */
  {YYNOCODE,0,0}, /* Unused */
/* State 139 */
  {YYNOCODE,0,0}, /* Unused */
/* State 140 */
  {YYNOCODE,0,0}, /* Unused */
/* State 141 */
  {YYNOCODE,0,0}, /* Unused */
/* State 142 */
  { 136, 147, 0                    }, /*                  value shift  147 */
  {  65, 143, &yyActionTable[ 256] }, /*             avp_oneoff shift  143 */
  {  49, 136, 0                    }, /*                 QUOTED shift  136 */
  {  13, 140, 0                    }, /*               DOTED_IP shift  140 */
  {  30, 139, &yyActionTable[ 261] }, /*                INTEGER shift  139 */
  {  21, 138, &yyActionTable[ 257] }, /*               FLOATING shift  138 */
  {  38, 137, &yyActionTable[ 258] }, /*                   NAME shift  137 */
  {   6, 141, 0                    }, /*              COLONIZED shift  141 */
/* State 143 */
  {   4, 144, 0                    }, /*            CLOSE_BRACE shift  144 */
  {  47, 145, 0                    }, /*                   PIPE shift  145 */
/* State 144 */
  {YYNOCODE,0,0}, /* Unused */
/* State 145 */
  { 136, 146, 0                    }, /*                  value shift  146 */
  {  49, 136, 0                    }, /*                 QUOTED shift  136 */
  {  13, 140, 0                    }, /*               DOTED_IP shift  140 */
  {  30, 139, &yyActionTable[ 269] }, /*                INTEGER shift  139 */
  {   6, 141, 0                    }, /*              COLONIZED shift  141 */
  {  21, 138, &yyActionTable[ 267] }, /*               FLOATING shift  138 */
  {  38, 137, &yyActionTable[ 268] }, /*                   NAME shift  137 */
  {YYNOCODE,0,0}, /* Unused */
/* State 146 */
  {YYNOCODE,0,0}, /* Unused */
/* State 147 */
  {YYNOCODE,0,0}, /* Unused */
/* State 148 */
  {YYNOCODE,0,0}, /* Unused */
/* State 149 */
  {YYNOCODE,0,0}, /* Unused */
/* State 150 */
  {  43, 346, 0                    }, /*            OPEN_PARENS reduce 64 */
/* State 151 */
  {  43, 347, 0                    }, /*            OPEN_PARENS reduce 65 */
/* State 152 */
  {  35, 157, 0                    }, /*               LOOSE_KW shift  157 */
  {  15, 156, 0                    }, /*               EVERY_KW shift  156 */
  {  58, 155, 0                    }, /*              STRICT_KW shift  155 */
  {  43, 342, &yyActionTable[ 279] }, /*            OPEN_PARENS reduce 60 */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  { 111, 153, &yyActionTable[ 280] }, /*             match_mode shift  153 */
/* State 153 */
  {  66, 154, 0                    }, /*                   avpl shift  154 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 154 */
  {YYNOCODE,0,0}, /* Unused */
/* State 155 */
  {  43, 343, 0                    }, /*            OPEN_PARENS reduce 61 */
/* State 156 */
  {  43, 344, 0                    }, /*            OPEN_PARENS reduce 62 */
/* State 157 */
  {  43, 345, 0                    }, /*            OPEN_PARENS reduce 63 */
/* State 158 */
  {YYNOCODE,0,0}, /* Unused */
/* State 159 */
  {  38, 160, 0                    }, /*                   NAME shift  160 */
/* State 160 */
  {  48, 161, 0                    }, /*               PROTO_KW shift  161 */
/* State 161 */
  {  80, 162, &yyActionTable[ 297] }, /*                  field shift  162 */
  {  38, 197, 0                    }, /*                   NAME shift  197 */
/* State 162 */
  {  60, 163, 0                    }, /*           TRANSPORT_KW shift  163 */
/* State 163 */
  {  80, 211, 0                    }, /*                  field shift  211 */
  {  38, 197, 0                    }, /*                   NAME shift  197 */
  { 122, 164, &yyActionTable[ 300] }, /*            proto_stack shift  164 */
  {YYNOCODE,0,0}, /* Unused */
/* State 164 */
  {  42, 165, 0                    }, /*             OPEN_BRACE shift  165 */
  {  55, 209, 0                    }, /*                  SLASH shift  209 */
/* State 165 */
  {  44, 206, 0                    }, /*             PAYLOAD_KW shift  206 */
  { 113, 166, &yyActionTable[ 307] }, /*      payload_statement shift  166 */
  {  17, 350, 0                    }, /*             EXTRACT_KW reduce 68 */
  {YYNOCODE,0,0}, /* Unused */
/* State 166 */
  {YYNOCODE,0,0}, /* Unused */
  {  17, 192, 0                    }, /*             EXTRACT_KW shift  192 */
  {  78, 205, 0                    }, /*   extraction_statement shift  205 */
  {  79, 167, 0                    }, /*  extraction_statements shift  167 */
/* State 167 */
  {  59, 198, 0                    }, /*           TRANSFORM_KW shift  198 */
  {  17, 192, 0                    }, /*             EXTRACT_KW shift  192 */
  {  78, 191, 0                    }, /*   extraction_statement shift  191 */
  { 131, 168, &yyActionTable[ 313] }, /* transform_list_statement shift  168 */
/* State 168 */
  {  68, 169, &yyActionTable[ 318] }, /*     criteria_statement shift  169 */
  {   8, 184, 0                    }, /*            CRITERIA_KW shift  184 */
/* State 169 */
  {  14, 181, 0                    }, /*     DROP_UNASSIGNED_KW shift  181 */
  { 119, 170, 0                    }, /* pdu_drop_unassigned_statement shift  170 */
/* State 170 */
  {  11, 178, 0                    }, /*    DISCARD_PDU_DATA_KW shift  178 */
  {  75, 171, &yyActionTable[ 321] }, /* discard_pdu_data_statement shift  171 */
/* State 171 */
  {  32, 175, &yyActionTable[ 325] }, /*            LAST_PDU_KW shift  175 */
  { 109, 172, 0                    }, /* last_extracted_statement shift  172 */
  {   4, 365, 0                    }, /*            CLOSE_BRACE reduce 83 */
  {YYNOCODE,0,0}, /* Unused */
/* State 172 */
  {   4, 173, 0                    }, /*            CLOSE_BRACE shift  173 */
/* State 173 */
  {  52, 174, 0                    }, /*              SEMICOLON shift  174 */
/* State 174 */
  {YYNOCODE,0,0}, /* Unused */
/* State 175 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 176, &yyActionTable[ 330] }, /*             true_false shift  176 */
/* State 176 */
  {  52, 177, 0                    }, /*              SEMICOLON shift  177 */
/* State 177 */
  {   4, 364, 0                    }, /*            CLOSE_BRACE reduce 82 */
/* State 178 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 179, &yyActionTable[ 336] }, /*             true_false shift  179 */
/* State 179 */
  {  52, 180, 0                    }, /*              SEMICOLON shift  180 */
/* State 180 */
  {YYNOCODE,0,0}, /* Unused */
/* State 181 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 182, &yyActionTable[ 342] }, /*             true_false shift  182 */
/* State 182 */
  {  52, 183, 0                    }, /*              SEMICOLON shift  183 */
/* State 183 */
  {YYNOCODE,0,0}, /* Unused */
/* State 184 */
  {  50, 190, 0                    }, /*              REJECT_KW shift  190 */
  {   1, 189, 0                    }, /*              ACCEPT_KW shift  189 */
  {  62, 185, &yyActionTable[ 348] }, /*            accept_mode shift  185 */
  {YYNOCODE,0,0}, /* Unused */
/* State 185 */
  {  35, 157, 0                    }, /*               LOOSE_KW shift  157 */
  {  15, 156, 0                    }, /*               EVERY_KW shift  156 */
  {  58, 155, 0                    }, /*              STRICT_KW shift  155 */
  {  43, 342, &yyActionTable[ 352] }, /*            OPEN_PARENS reduce 60 */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  { 111, 186, &yyActionTable[ 353] }, /*             match_mode shift  186 */
/* State 186 */
  {  66, 187, 0                    }, /*                   avpl shift  187 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 187 */
  {  52, 188, 0                    }, /*              SEMICOLON shift  188 */
/* State 188 */
  {YYNOCODE,0,0}, /* Unused */
/* State 189 */
  {YYNOCODE,0,0}, /* Unused */
/* State 190 */
  {YYNOCODE,0,0}, /* Unused */
/* State 191 */
  {YYNOCODE,0,0}, /* Unused */
/* State 192 */
  {  38, 193, 0                    }, /*                   NAME shift  193 */
/* State 193 */
  {  23, 194, 0                    }, /*                FROM_KW shift  194 */
/* State 194 */
  {  80, 195, &yyActionTable[ 370] }, /*                  field shift  195 */
  {  38, 197, 0                    }, /*                   NAME shift  197 */
/* State 195 */
  {  52, 196, 0                    }, /*              SEMICOLON shift  196 */
/* State 196 */
  {YYNOCODE,0,0}, /* Unused */
/* State 197 */
  {YYNOCODE,0,0}, /* Unused */
/* State 198 */
  { 126, 204, &yyActionTable[ 375] }, /*              transform shift  204 */
  {  38, 203, 0                    }, /*                   NAME shift  203 */
  { 130, 199, &yyActionTable[ 374] }, /*         transform_list shift  199 */
  {YYNOCODE,0,0}, /* Unused */
/* State 199 */
  {  52, 200, 0                    }, /*              SEMICOLON shift  200 */
  {   7, 201, 0                    }, /*                  COMMA shift  201 */
/* State 200 */
  {YYNOCODE,0,0}, /* Unused */
/* State 201 */
  { 126, 202, &yyActionTable[ 382] }, /*              transform shift  202 */
  {  38, 203, 0                    }, /*                   NAME shift  203 */
/* State 202 */
  {YYNOCODE,0,0}, /* Unused */
/* State 203 */
  {YYNOCODE,0,0}, /* Unused */
/* State 204 */
  {YYNOCODE,0,0}, /* Unused */
/* State 205 */
  {YYNOCODE,0,0}, /* Unused */
/* State 206 */
  {  80, 211, 0                    }, /*                  field shift  211 */
  {  38, 197, 0                    }, /*                   NAME shift  197 */
  { 122, 207, &yyActionTable[ 388] }, /*            proto_stack shift  207 */
  {YYNOCODE,0,0}, /* Unused */
/* State 207 */
  {  52, 208, 0                    }, /*              SEMICOLON shift  208 */
  {  55, 209, 0                    }, /*                  SLASH shift  209 */
/* State 208 */
  {  17, 351, 0                    }, /*             EXTRACT_KW reduce 69 */
/* State 209 */
  {  80, 210, &yyActionTable[ 395] }, /*                  field shift  210 */
  {  38, 197, 0                    }, /*                   NAME shift  197 */
/* State 210 */
  {YYNOCODE,0,0}, /* Unused */
/* State 211 */
  {YYNOCODE,0,0}, /* Unused */
/* State 212 */
  {  38, 213, 0                    }, /*                   NAME shift  213 */
/* State 213 */
  {  41, 214, 0                    }, /*                  ON_KW shift  214 */
/* State 214 */
  {  38, 258, 0                    }, /*                   NAME shift  258 */
  { 121, 215, 0                    }, /*               pdu_name shift  215 */
/* State 215 */
  {  36, 216, 0                    }, /*               MATCH_KW shift  216 */
/* State 216 */
  {  66, 217, 0                    }, /*                   avpl shift  217 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 217 */
  {  42, 218, 0                    }, /*             OPEN_BRACE shift  218 */
/* State 218 */
  {  56, 255, 0                    }, /*               START_KW shift  255 */
  { 103, 219, 0                    }, /*    gop_start_statement shift  219 */
/* State 219 */
  { 104, 220, 0                    }, /*     gop_stop_statement shift  220 */
  {  57, 252, 0                    }, /*                STOP_KW shift  252 */
/* State 220 */
  {  18, 249, 0                    }, /*               EXTRA_KW shift  249 */
  {  77, 221, 0                    }, /*        extra_statement shift  221 */
/* State 221 */
  {  59, 198, 0                    }, /*           TRANSFORM_KW shift  198 */
  { 131, 222, &yyActionTable[ 412] }, /* transform_list_statement shift  222 */
/* State 222 */
  {  16, 246, 0                    }, /*          EXPIRATION_KW shift  246 */
  {  97, 223, 0                    }, /* gop_expiration_statement shift  223 */
/* State 223 */
  { 108, 224, &yyActionTable[ 417] }, /* idle_timeout_statement shift  224 */
  {  28, 243, 0                    }, /*        IDLE_TIMEOUT_KW shift  243 */
/* State 224 */
  { 110, 225, &yyActionTable[ 419] }, /*     lifetime_statement shift  225 */
  {  34, 240, 0                    }, /*            LIFETIME_KW shift  240 */
/* State 225 */
  {  14, 237, 0                    }, /*     DROP_UNASSIGNED_KW shift  237 */
  {  95, 226, 0                    }, /* gop_drop_unassigned_statement shift  226 */
/* State 226 */
  {  54, 234, 0                    }, /*           SHOW_TREE_KW shift  234 */
  { 123, 227, 0                    }, /* show_goptree_statement shift  227 */
/* State 227 */
  { 124, 228, &yyActionTable[ 426] }, /*   show_times_statement shift  228 */
  {  53, 231, 0                    }, /*          SHOW_TIMES_KW shift  231 */
  {   4, 379, 0                    }, /*            CLOSE_BRACE reduce 97 */
  {YYNOCODE,0,0}, /* Unused */
/* State 228 */
  {   4, 229, 0                    }, /*            CLOSE_BRACE shift  229 */
/* State 229 */
  {  52, 230, 0                    }, /*              SEMICOLON shift  230 */
/* State 230 */
  {YYNOCODE,0,0}, /* Unused */
/* State 231 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 232, &yyActionTable[ 431] }, /*             true_false shift  232 */
/* State 232 */
  {  52, 233, 0                    }, /*              SEMICOLON shift  233 */
/* State 233 */
  {   4, 378, 0                    }, /*            CLOSE_BRACE reduce 96 */
/* State 234 */
  {  22,  55, 0                    }, /*          FRAME_TREE_KW shift  55 */
  { 105, 235, 0                    }, /*          gop_tree_mode shift  235 */
  {YYNOCODE,0,0}, /* Unused */
  {   3,  56, 0                    }, /*          BASIC_TREE_KW shift  56 */
  {YYNOCODE,0,0}, /* Unused */
  {YYNOCODE,0,0}, /* Unused */
  {  46,  54, &yyActionTable[ 437] }, /*            PDU_TREE_KW shift  54 */
  {  39,  53, 0                    }, /*             NO_TREE_KW shift  53 */
/* State 235 */
  {  52, 236, 0                    }, /*              SEMICOLON shift  236 */
/* State 236 */
  {YYNOCODE,0,0}, /* Unused */
/* State 237 */
  {  19,  86, 0                    }, /*               FALSE_KW shift  86 */
  {  61,  85, 0                    }, /*                TRUE_KW shift  85 */
  {YYNOCODE,0,0}, /* Unused */
  { 135, 238, &yyActionTable[ 447] }, /*             true_false shift  238 */
/* State 238 */
  {  52, 239, 0                    }, /*              SEMICOLON shift  239 */
/* State 239 */
  {YYNOCODE,0,0}, /* Unused */
/* State 240 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125, 241, &yyActionTable[ 453] }, /*             time_value shift  241 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 241 */
  {  52, 242, 0                    }, /*              SEMICOLON shift  242 */
/* State 242 */
  {YYNOCODE,0,0}, /* Unused */
/* State 243 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125, 244, &yyActionTable[ 459] }, /*             time_value shift  244 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 244 */
  {  52, 245, 0                    }, /*              SEMICOLON shift  245 */
/* State 245 */
  {YYNOCODE,0,0}, /* Unused */
/* State 246 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125, 247, &yyActionTable[ 465] }, /*             time_value shift  247 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 247 */
  {  52, 248, 0                    }, /*              SEMICOLON shift  248 */
/* State 248 */
  {YYNOCODE,0,0}, /* Unused */
/* State 249 */
  {  66, 250, 0                    }, /*                   avpl shift  250 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 250 */
  {  52, 251, 0                    }, /*              SEMICOLON shift  251 */
/* State 251 */
  {YYNOCODE,0,0}, /* Unused */
/* State 252 */
  {  66, 253, 0                    }, /*                   avpl shift  253 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 253 */
  {  52, 254, 0                    }, /*              SEMICOLON shift  254 */
/* State 254 */
  {YYNOCODE,0,0}, /* Unused */
/* State 255 */
  {  66, 256, 0                    }, /*                   avpl shift  256 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 256 */
  {  52, 257, 0                    }, /*              SEMICOLON shift  257 */
/* State 257 */
  {YYNOCODE,0,0}, /* Unused */
/* State 258 */
  {  36, 392, 0                    }, /*               MATCH_KW reduce 110 */
/* State 259 */
  {  38, 260, 0                    }, /*                   NAME shift  260 */
/* State 260 */
  {  42, 261, 0                    }, /*             OPEN_BRACE shift  261 */
/* State 261 */
  {  88, 281, 0                    }, /*      gog_key_statement shift  281 */
  {  89, 262, &yyActionTable[ 488] }, /*     gog_key_statements shift  262 */
  {  37, 276, 0                    }, /*              MEMBER_KW shift  276 */
  {YYNOCODE,0,0}, /* Unused */
/* State 262 */
  {  88, 275, 0                    }, /*      gog_key_statement shift  275 */
  {  77, 263, &yyActionTable[ 493] }, /*        extra_statement shift  263 */
  {  18, 249, 0                    }, /*               EXTRA_KW shift  249 */
  {  37, 276, 0                    }, /*              MEMBER_KW shift  276 */
/* State 263 */
  {  59, 198, 0                    }, /*           TRANSFORM_KW shift  198 */
  { 131, 264, &yyActionTable[ 494] }, /* transform_list_statement shift  264 */
/* State 264 */
  {  16, 272, 0                    }, /*          EXPIRATION_KW shift  272 */
  {  85, 265, 0                    }, /* gog_expiration_statement shift  265 */
/* State 265 */
  {   4, 397, 0                    }, /*            CLOSE_BRACE reduce 115 */
  {  27, 269, 0                    }, /*            GOP_TREE_KW shift  269 */
  {YYNOCODE,0,0}, /* Unused */
  {  87, 266, &yyActionTable[ 499] }, /*  gog_goptree_statement shift  266 */
/* State 266 */
  {   4, 267, 0                    }, /*            CLOSE_BRACE shift  267 */
/* State 267 */
  {  52, 268, 0                    }, /*              SEMICOLON shift  268 */
/* State 268 */
  {YYNOCODE,0,0}, /* Unused */
/* State 269 */
  {  40,  64, &yyActionTable[ 506] }, /*           NULL_TREE_KW shift  64 */
  {  24,  65, 0                    }, /*           FULL_TREE_KW shift  65 */
  {   3,  66, 0                    }, /*          BASIC_TREE_KW shift  66 */
  { 107, 270, &yyActionTable[ 507] }, /*          gop_tree_type shift  270 */
/* State 270 */
  {  52, 271, 0                    }, /*              SEMICOLON shift  271 */
/* State 271 */
  {   4, 396, 0                    }, /*            CLOSE_BRACE reduce 114 */
/* State 272 */
  {  21,  70, 0                    }, /*               FLOATING shift  70 */
  { 125, 273, &yyActionTable[ 511] }, /*             time_value shift  273 */
  {  30,  71, 0                    }, /*                INTEGER shift  71 */
  {YYNOCODE,0,0}, /* Unused */
/* State 273 */
  {  52, 274, 0                    }, /*              SEMICOLON shift  274 */
/* State 274 */
  {YYNOCODE,0,0}, /* Unused */
/* State 275 */
  {YYNOCODE,0,0}, /* Unused */
/* State 276 */
  { 100, 277, &yyActionTable[ 519] }, /*               gop_name shift  277 */
  {  38, 280, 0                    }, /*                   NAME shift  280 */
/* State 277 */
  {  66, 278, 0                    }, /*                   avpl shift  278 */
  {  43, 128, 0                    }, /*            OPEN_PARENS shift  128 */
/* State 278 */
  {  52, 279, 0                    }, /*              SEMICOLON shift  279 */
/* State 279 */
  {YYNOCODE,0,0}, /* Unused */
/* State 280 */
  {  43, 406, 0                    }, /*            OPEN_PARENS reduce 124 */
/* State 281 */
  {YYNOCODE,0,0}, /* Unused */
};

/* The state table contains information needed to look up the correct
** action in the action table, given the current state of the parser.
** Information needed includes:
**
**  +  A pointer to the start of the action hash table in yyActionTable.
**
**  +  A mask used to hash the look-ahead token.  The mask is an integer
**     which is one less than the size of the hash table.
**
**  +  The default action.  This is the action to take if no entry for
**     the given look-ahead is found in the action hash table.
*/
struct yyStateEntry {
  struct yyActionEntry *hashtbl; /* Start of the hash table in yyActionTable */
  int mask;                      /* Mask used for hashing the look-ahead */
  YYACTIONTYPE actionDefault;    /* Default action if look-ahead not found */
};
static struct yyStateEntry yyStateTable[] = {
  { &yyActionTable[0], 1, 284},
  { &yyActionTable[2], 15, 429},
  { &yyActionTable[18], 0, 283},
  { &yyActionTable[19], 0, 285},
  { &yyActionTable[20], 0, 286},
  { &yyActionTable[21], 0, 287},
  { &yyActionTable[22], 0, 288},
  { &yyActionTable[23], 0, 289},
  { &yyActionTable[24], 0, 290},
  { &yyActionTable[25], 0, 429},
  { &yyActionTable[26], 0, 291},
  { &yyActionTable[27], 0, 429},
  { &yyActionTable[28], 1, 295},
  { &yyActionTable[30], 1, 297},
  { &yyActionTable[32], 1, 299},
  { &yyActionTable[34], 1, 301},
  { &yyActionTable[36], 3, 429},
  { &yyActionTable[40], 0, 429},
  { &yyActionTable[41], 0, 429},
  { &yyActionTable[42], 0, 292},
  { &yyActionTable[43], 0, 429},
  { &yyActionTable[44], 0, 429},
  { &yyActionTable[45], 0, 429},
  { &yyActionTable[46], 0, 429},
  { &yyActionTable[47], 0, 429},
  { &yyActionTable[48], 0, 429},
  { &yyActionTable[49], 0, 429},
  { &yyActionTable[50], 0, 300},
  { &yyActionTable[51], 0, 429},
  { &yyActionTable[52], 0, 429},
  { &yyActionTable[53], 0, 429},
  { &yyActionTable[54], 0, 298},
  { &yyActionTable[55], 0, 429},
  { &yyActionTable[56], 0, 429},
  { &yyActionTable[57], 0, 296},
  { &yyActionTable[58], 1, 429},
  { &yyActionTable[60], 0, 429},
  { &yyActionTable[61], 0, 293},
  { &yyActionTable[62], 0, 429},
  { &yyActionTable[63], 0, 294},
  { &yyActionTable[64], 0, 429},
  { &yyActionTable[65], 1, 306},
  { &yyActionTable[67], 1, 314},
  { &yyActionTable[69], 3, 429},
  { &yyActionTable[73], 0, 429},
  { &yyActionTable[74], 0, 429},
  { &yyActionTable[75], 0, 304},
  { &yyActionTable[76], 0, 429},
  { &yyActionTable[77], 1, 330},
  { &yyActionTable[79], 1, 324},
  { &yyActionTable[81], 7, 429},
  { &yyActionTable[89], 0, 429},
  { &yyActionTable[90], 0, 323},
  { &yyActionTable[91], 0, 429},
  { &yyActionTable[92], 0, 429},
  { &yyActionTable[93], 0, 429},
  { &yyActionTable[94], 0, 429},
  { &yyActionTable[95], 3, 429},
  { &yyActionTable[99], 0, 429},
  { &yyActionTable[100], 0, 429},
  { &yyActionTable[101], 0, 429},
  { &yyActionTable[102], 3, 429},
  { &yyActionTable[106], 0, 429},
  { &yyActionTable[107], 0, 429},
  { &yyActionTable[108], 0, 429},
  { &yyActionTable[109], 0, 429},
  { &yyActionTable[110], 0, 429},
  { &yyActionTable[111], 3, 429},
  { &yyActionTable[115], 0, 429},
  { &yyActionTable[116], 0, 329},
  { &yyActionTable[117], 0, 429},
  { &yyActionTable[118], 0, 429},
  { &yyActionTable[119], 0, 429},
  { &yyActionTable[120], 1, 316},
  { &yyActionTable[122], 1, 318},
  { &yyActionTable[124], 1, 320},
  { &yyActionTable[126], 1, 322},
  { &yyActionTable[128], 1, 324},
  { &yyActionTable[130], 3, 429},
  { &yyActionTable[134], 0, 429},
  { &yyActionTable[135], 0, 429},
  { &yyActionTable[136], 0, 313},
  { &yyActionTable[137], 3, 429},
  { &yyActionTable[141], 0, 429},
  { &yyActionTable[142], 0, 429},
  { &yyActionTable[143], 0, 429},
  { &yyActionTable[144], 0, 429},
  { &yyActionTable[145], 3, 429},
  { &yyActionTable[149], 0, 429},
  { &yyActionTable[150], 0, 321},
  { &yyActionTable[151], 3, 429},
  { &yyActionTable[155], 0, 429},
  { &yyActionTable[156], 0, 319},
  { &yyActionTable[157], 3, 429},
  { &yyActionTable[161], 0, 429},
  { &yyActionTable[162], 0, 317},
  { &yyActionTable[163], 3, 429},
  { &yyActionTable[167], 0, 429},
  { &yyActionTable[168], 0, 315},
  { &yyActionTable[169], 0, 429},
  { &yyActionTable[170], 1, 308},
  { &yyActionTable[172], 1, 310},
  { &yyActionTable[174], 3, 429},
  { &yyActionTable[178], 0, 429},
  { &yyActionTable[179], 0, 429},
  { &yyActionTable[180], 0, 305},
  { &yyActionTable[181], 3, 429},
  { &yyActionTable[185], 0, 429},
  { &yyActionTable[186], 0, 429},
  { &yyActionTable[187], 3, 429},
  { &yyActionTable[191], 0, 429},
  { &yyActionTable[192], 0, 309},
  { &yyActionTable[193], 3, 429},
  { &yyActionTable[197], 0, 429},
  { &yyActionTable[198], 0, 307},
  { &yyActionTable[199], 0, 429},
  { &yyActionTable[200], 1, 429},
  { &yyActionTable[202], 0, 429},
  { &yyActionTable[203], 0, 333},
  { &yyActionTable[204], 3, 339},
  { &yyActionTable[208], 3, 339},
  { &yyActionTable[212], 0, 429},
  { &yyActionTable[213], 0, 335},
  { &yyActionTable[214], 7, 429},
  { &yyActionTable[222], 0, 429},
  { &yyActionTable[223], 0, 337},
  { &yyActionTable[224], 1, 429},
  { &yyActionTable[226], 0, 429},
  { &yyActionTable[227], 3, 429},
  { &yyActionTable[231], 1, 429},
  { &yyActionTable[233], 0, 414},
  { &yyActionTable[234], 1, 429},
  { &yyActionTable[236], 0, 416},
  { &yyActionTable[237], 1, 419},
  { &yyActionTable[239], 7, 429},
  { &yyActionTable[247], 0, 418},
  { &yyActionTable[248], 0, 423},
  { &yyActionTable[249], 0, 424},
  { &yyActionTable[250], 0, 425},
  { &yyActionTable[251], 0, 426},
  { &yyActionTable[252], 0, 427},
  { &yyActionTable[253], 0, 428},
  { &yyActionTable[254], 7, 429},
  { &yyActionTable[262], 1, 429},
  { &yyActionTable[264], 0, 420},
  { &yyActionTable[265], 7, 429},
  { &yyActionTable[273], 0, 421},
  { &yyActionTable[274], 0, 422},
  { &yyActionTable[275], 0, 415},
  { &yyActionTable[276], 0, 417},
  { &yyActionTable[277], 0, 429},
  { &yyActionTable[278], 0, 429},
  { &yyActionTable[279], 7, 429},
  { &yyActionTable[287], 1, 429},
  { &yyActionTable[289], 0, 338},
  { &yyActionTable[290], 0, 429},
  { &yyActionTable[291], 0, 429},
  { &yyActionTable[292], 0, 429},
  { &yyActionTable[293], 0, 336},
  { &yyActionTable[294], 0, 429},
  { &yyActionTable[295], 0, 429},
  { &yyActionTable[296], 1, 429},
  { &yyActionTable[298], 0, 429},
  { &yyActionTable[299], 3, 429},
  { &yyActionTable[303], 1, 429},
  { &yyActionTable[305], 3, 429},
  { &yyActionTable[309], 3, 429},
  { &yyActionTable[313], 3, 410},
  { &yyActionTable[317], 1, 352},
  { &yyActionTable[319], 1, 361},
  { &yyActionTable[321], 1, 363},
  { &yyActionTable[323], 3, 429},
  { &yyActionTable[327], 0, 429},
  { &yyActionTable[328], 0, 429},
  { &yyActionTable[329], 0, 349},
  { &yyActionTable[330], 3, 429},
  { &yyActionTable[334], 0, 429},
  { &yyActionTable[335], 0, 429},
  { &yyActionTable[336], 3, 429},
  { &yyActionTable[340], 0, 429},
  { &yyActionTable[341], 0, 362},
  { &yyActionTable[342], 3, 429},
  { &yyActionTable[346], 0, 429},
  { &yyActionTable[347], 0, 360},
  { &yyActionTable[348], 3, 354},
  { &yyActionTable[352], 7, 429},
  { &yyActionTable[360], 1, 429},
  { &yyActionTable[362], 0, 429},
  { &yyActionTable[363], 0, 353},
  { &yyActionTable[364], 0, 355},
  { &yyActionTable[365], 0, 356},
  { &yyActionTable[366], 0, 357},
  { &yyActionTable[367], 0, 429},
  { &yyActionTable[368], 0, 429},
  { &yyActionTable[369], 1, 429},
  { &yyActionTable[371], 0, 429},
  { &yyActionTable[372], 0, 359},
  { &yyActionTable[373], 0, 368},
  { &yyActionTable[374], 3, 429},
  { &yyActionTable[378], 1, 429},
  { &yyActionTable[380], 0, 409},
  { &yyActionTable[381], 1, 429},
  { &yyActionTable[383], 0, 411},
  { &yyActionTable[384], 0, 413},
  { &yyActionTable[385], 0, 412},
  { &yyActionTable[386], 0, 358},
  { &yyActionTable[387], 3, 429},
  { &yyActionTable[391], 1, 429},
  { &yyActionTable[393], 0, 429},
  { &yyActionTable[394], 1, 429},
  { &yyActionTable[396], 0, 366},
  { &yyActionTable[397], 0, 367},
  { &yyActionTable[398], 0, 429},
  { &yyActionTable[399], 0, 429},
  { &yyActionTable[400], 1, 429},
  { &yyActionTable[402], 0, 429},
  { &yyActionTable[403], 1, 429},
  { &yyActionTable[405], 0, 429},
  { &yyActionTable[406], 1, 373},
  { &yyActionTable[408], 1, 375},
  { &yyActionTable[410], 1, 408},
  { &yyActionTable[412], 1, 410},
  { &yyActionTable[414], 1, 381},
  { &yyActionTable[416], 1, 383},
  { &yyActionTable[418], 1, 385},
  { &yyActionTable[420], 1, 371},
  { &yyActionTable[422], 1, 377},
  { &yyActionTable[424], 3, 429},
  { &yyActionTable[428], 0, 429},
  { &yyActionTable[429], 0, 429},
  { &yyActionTable[430], 0, 369},
  { &yyActionTable[431], 3, 429},
  { &yyActionTable[435], 0, 429},
  { &yyActionTable[436], 0, 429},
  { &yyActionTable[437], 7, 429},
  { &yyActionTable[445], 0, 429},
  { &yyActionTable[446], 0, 376},
  { &yyActionTable[447], 3, 429},
  { &yyActionTable[451], 0, 429},
  { &yyActionTable[452], 0, 370},
  { &yyActionTable[453], 3, 429},
  { &yyActionTable[457], 0, 429},
  { &yyActionTable[458], 0, 384},
  { &yyActionTable[459], 3, 429},
  { &yyActionTable[463], 0, 429},
  { &yyActionTable[464], 0, 382},
  { &yyActionTable[465], 3, 429},
  { &yyActionTable[469], 0, 429},
  { &yyActionTable[470], 0, 380},
  { &yyActionTable[471], 1, 429},
  { &yyActionTable[473], 0, 429},
  { &yyActionTable[474], 0, 407},
  { &yyActionTable[475], 1, 429},
  { &yyActionTable[477], 0, 429},
  { &yyActionTable[478], 0, 374},
  { &yyActionTable[479], 1, 429},
  { &yyActionTable[481], 0, 429},
  { &yyActionTable[482], 0, 372},
  { &yyActionTable[483], 0, 429},
  { &yyActionTable[484], 0, 429},
  { &yyActionTable[485], 0, 429},
  { &yyActionTable[486], 3, 429},
  { &yyActionTable[490], 3, 408},
  { &yyActionTable[494], 1, 410},
  { &yyActionTable[496], 1, 399},
  { &yyActionTable[498], 3, 429},
  { &yyActionTable[502], 0, 429},
  { &yyActionTable[503], 0, 429},
  { &yyActionTable[504], 0, 395},
  { &yyActionTable[505], 3, 429},
  { &yyActionTable[509], 0, 429},
  { &yyActionTable[510], 0, 429},
  { &yyActionTable[511], 3, 429},
  { &yyActionTable[515], 0, 429},
  { &yyActionTable[516], 0, 398},
  { &yyActionTable[517], 0, 403},
  { &yyActionTable[518], 1, 429},
  { &yyActionTable[520], 1, 429},
  { &yyActionTable[522], 0, 429},
  { &yyActionTable[523], 0, 405},
  { &yyActionTable[524], 0, 429},
  { &yyActionTable[525], 0, 404},
};

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  int stateno;       /* The state-number */
  int major;         /* The major token value.  This is the code
                     ** number for the token at this stack level */
  YYMINORTYPE minor; /* The user-supplied minor token value.  This
                     ** is the value of the token  */
};

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int idx;                            /* Index of top element in stack */
  int errcnt;                         /* Shifts left before out of the error */
  struct yyStackEntry *top;           /* Pointer to the top stack element */
  struct yyStackEntry stack[YYSTACKDEPTH];  /* The parser's stack */
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;

/*
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void MateParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}

/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *yyTokenName[] = {
  "$",             "ACCEPT_KW",     "AVP_OPERATOR",  "BASIC_TREE_KW",
  "CLOSE_BRACE",   "CLOSE_PARENS",  "COLONIZED",     "COMMA",       
  "CRITERIA_KW",   "DEBUG_KW",      "DEFAULT_KW",    "DISCARD_PDU_DATA_KW",
  "DONE_KW",       "DOTED_IP",      "DROP_UNASSIGNED_KW",  "EVERY_KW",    
  "EXPIRATION_KW",  "EXTRACT_KW",    "EXTRA_KW",      "FALSE_KW",    
  "FILENAME_KW",   "FLOATING",      "FRAME_TREE_KW",  "FROM_KW",     
  "FULL_TREE_KW",  "GOG_KW",        "GOP_KW",        "GOP_TREE_KW", 
  "IDLE_TIMEOUT_KW",  "INSERT_KW",     "INTEGER",       "LAST_EXTRACTED_KW",
  "LAST_PDU_KW",   "LEVEL_KW",      "LIFETIME_KW",   "LOOSE_KW",    
  "MATCH_KW",      "MEMBER_KW",     "NAME",          "NO_TREE_KW",  
  "NULL_TREE_KW",  "ON_KW",         "OPEN_BRACE",    "OPEN_PARENS", 
  "PAYLOAD_KW",    "PDU_KW",        "PDU_TREE_KW",   "PIPE",        
  "PROTO_KW",      "QUOTED",        "REJECT_KW",     "REPLACE_KW",  
  "SEMICOLON",     "SHOW_TIMES_KW",  "SHOW_TREE_KW",  "SLASH",       
  "START_KW",      "STOP_KW",       "STRICT_KW",     "TRANSFORM_KW",
  "TRANSPORT_KW",  "TRUE_KW",       "accept_mode",   "action_mode", 
  "avp",           "avp_oneoff",    "avpl",          "avps",        
  "criteria_statement",  "dbgfile_default",  "dbglevel_default",  "debug_decl",  
  "decl",          "decls",         "defaults_decl",  "discard_pdu_data_statement",
  "error",         "extra_statement",  "extraction_statement",  "extraction_statements",
  "field",         "gog_dbglevel_default",  "gog_decl",      "gog_defaults",
  "gog_expiration_default",  "gog_expiration_statement",  "gog_goptree_default",  "gog_goptree_statement",
  "gog_key_statement",  "gog_key_statements",  "gog_statements",  "gop_dbglevel_default",
  "gop_decl",      "gop_defaults",  "gop_drop_unassigned_default",  "gop_drop_unassigned_statement",
  "gop_expiration_default",  "gop_expiration_statement",  "gop_idle_timeout_default",  "gop_lifetime_default",
  "gop_name",      "gop_options",   "gop_show_times_default",  "gop_start_statement",
  "gop_stop_statement",  "gop_tree_mode",  "gop_tree_mode_default",  "gop_tree_type",
  "idle_timeout_statement",  "last_extracted_statement",  "lifetime_statement",  "match_mode",  
  "mate_config",   "payload_statement",  "pdu_dbglevel_default",  "pdu_decl",    
  "pdu_defaults",  "pdu_discard_default",  "pdu_drop_unassigned_default",  "pdu_drop_unassigned_statement",
  "pdu_last_extracted_default",  "pdu_name",      "proto_stack",   "show_goptree_statement",
  "show_times_statement",  "time_value",    "transform",     "transform_action",
  "transform_body",  "transform_decl",  "transform_list",  "transform_list_statement",
  "transform_match",  "transform_statement",  "transform_statements",  "true_false",  
  "value",       
};
#define YYTRACE(X) if( yyTraceFILE ) fprintf(yyTraceFILE,"%sReduce [%s].\n",yyTracePrompt,X);
#else
#define YYTRACE(X)
#endif

/*
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to MateParser and MateParserFree.
*/
void *MateParserAlloc(void *(*mallocProc)(gulong)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( sizeof(yyParser) );
  if( pParser ){
    pParser->idx = -1;
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 1:
    case 2:
    case 3:
    case 4:
    case 5:
    case 6:
    case 7:
    case 8:
    case 9:
    case 10:
    case 11:
    case 12:
    case 13:
    case 14:
    case 15:
    case 16:
    case 17:
    case 18:
    case 19:
    case 20:
    case 21:
    case 22:
    case 23:
    case 24:
    case 25:
    case 26:
    case 27:
    case 28:
    case 29:
    case 30:
    case 31:
    case 32:
    case 33:
    case 34:
    case 35:
    case 36:
    case 37:
    case 38:
    case 39:
    case 40:
    case 41:
    case 42:
    case 43:
    case 44:
    case 45:
    case 46:
    case 47:
    case 48:
    case 49:
    case 50:
    case 51:
    case 52:
    case 53:
    case 54:
    case 55:
    case 56:
    case 57:
    case 58:
    case 59:
    case 60:
    case 61:
#line 180 "./mate_grammar.lemon"
{ if ((yypminor->yy0)) g_free((yypminor->yy0)); }
#line 1624 "mate_grammar.c"
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;

  if( pParser->idx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->idx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[pParser->top->major]);
  }
#endif
  yymajor = pParser->top->major;
  yy_destructor( yymajor, &pParser->top->minor);
  pParser->idx--;
  pParser->top--;
  return yymajor;
}

/*
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from MateParserAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void MateParserFree(
  void *p,                 /* The parser to be deleted */
  void (*freeProc)(void *) /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->idx>=0 ) yy_pop_parser_stack(pParser);
  (*freeProc)(pParser);
}

/*
** Find the appropriate action for a parser given the look-ahead token.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_parser_action(
  yyParser *pParser,        /* The parser */
  int iLookAhead             /* The look-ahead token */
){
  struct yyStateEntry *pState;   /* Appropriate entry in the state table */
  struct yyActionEntry *pAction; /* Action appropriate for the look-ahead */

  /* if( pParser->idx<0 ) return YY_NO_ACTION;  */
  pState = &yyStateTable[pParser->top->stateno];
  if( iLookAhead!=YYNOCODE ){
    pAction = &pState->hashtbl[iLookAhead & pState->mask];
    while( pAction ){
      if( pAction->lookahead==iLookAhead ) return pAction->action;
      pAction = pAction->next;
    }
  }else if( pState->mask!=0 || pState->hashtbl->lookahead!=YYNOCODE ){
    return YY_NO_ACTION;
  }
  return pState->actionDefault;
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer ot the minor token to shift in */
){
  yypParser->idx++;
  yypParser->top++;
  if( yypParser->idx>=YYSTACKDEPTH ){
     yypParser->idx--;
     yypParser->top--;
#ifndef NDEBUG
     if( yyTraceFILE ){
       fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     }
#endif
     while( yypParser->idx>=0 ) yy_pop_parser_stack(yypParser);
     /* Here code is inserted which will execute if the parser
     ** stack every overflows */
     return;
  }
  yypParser->top->stateno = yyNewState;
  yypParser->top->major = yyMajor;
  yypParser->top->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->idx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->idx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->stack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 112, 1 },
  { 73, 2 },
  { 73, 0 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 1 },
  { 72, 2 },
  { 71, 9 },
  { 69, 3 },
  { 69, 3 },
  { 69, 0 },
  { 70, 3 },
  { 70, 0 },
  { 114, 4 },
  { 114, 0 },
  { 91, 4 },
  { 91, 0 },
  { 81, 4 },
  { 81, 0 },
  { 74, 7 },
  { 116, 7 },
  { 116, 0 },
  { 120, 3 },
  { 120, 0 },
  { 118, 3 },
  { 118, 0 },
  { 117, 3 },
  { 117, 0 },
  { 93, 10 },
  { 93, 0 },
  { 96, 3 },
  { 96, 0 },
  { 98, 3 },
  { 98, 0 },
  { 99, 3 },
  { 99, 0 },
  { 94, 3 },
  { 94, 0 },
  { 106, 3 },
  { 106, 0 },
  { 102, 3 },
  { 102, 0 },
  { 83, 7 },
  { 83, 0 },
  { 84, 3 },
  { 84, 0 },
  { 86, 3 },
  { 86, 0 },
  { 129, 4 },
  { 128, 3 },
  { 134, 2 },
  { 134, 1 },
  { 133, 3 },
  { 132, 3 },
  { 132, 0 },
  { 127, 0 },
  { 127, 2 },
  { 111, 0 },
  { 111, 1 },
  { 111, 1 },
  { 111, 1 },
  { 63, 1 },
  { 63, 1 },
  { 63, 0 },
  { 115, 16 },
  { 113, 0 },
  { 113, 3 },
  { 68, 0 },
  { 68, 5 },
  { 62, 0 },
  { 62, 1 },
  { 62, 1 },
  { 79, 2 },
  { 79, 1 },
  { 78, 5 },
  { 119, 3 },
  { 119, 0 },
  { 75, 3 },
  { 75, 0 },
  { 109, 3 },
  { 109, 0 },
  { 122, 3 },
  { 122, 1 },
  { 80, 1 },
  { 92, 19 },
  { 95, 3 },
  { 95, 0 },
  { 103, 3 },
  { 103, 0 },
  { 104, 3 },
  { 104, 0 },
  { 123, 3 },
  { 123, 0 },
  { 124, 3 },
  { 124, 0 },
  { 97, 3 },
  { 97, 0 },
  { 108, 3 },
  { 108, 0 },
  { 110, 3 },
  { 110, 0 },
  { 105, 1 },
  { 105, 1 },
  { 105, 1 },
  { 105, 1 },
  { 135, 1 },
  { 135, 1 },
  { 121, 1 },
  { 125, 1 },
  { 125, 1 },
  { 82, 10 },
  { 87, 3 },
  { 87, 0 },
  { 85, 3 },
  { 85, 0 },
  { 107, 1 },
  { 107, 1 },
  { 107, 1 },
  { 89, 2 },
  { 89, 1 },
  { 88, 4 },
  { 100, 1 },
  { 77, 3 },
  { 77, 0 },
  { 131, 3 },
  { 131, 0 },
  { 130, 3 },
  { 130, 1 },
  { 126, 1 },
  { 66, 3 },
  { 66, 2 },
  { 67, 3 },
  { 67, 1 },
  { 64, 3 },
  { 64, 1 },
  { 64, 4 },
  { 65, 3 },
  { 65, 1 },
  { 136, 1 },
  { 136, 1 },
  { 136, 1 },
  { 136, 1 },
  { 136, 1 },
  { 136, 1 },
};

static void yy_accept(
  yyParser *yypParser           /* The parser */
  MateParserANSIARGDECL _U_          /* Extra arguments (if any) */
);  /* Forward declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
  MateParserANSIARGDECL
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  struct yyStackEntry *yymsp;     /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  yymsp = yypParser->top;
  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **     YYTRACE("<text of the rule>");
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0:
        YYTRACE("mate_config ::= decls")
        /* No destructor defined for decls */
        break;
      case 1:
        YYTRACE("decls ::= decls decl")
        /* No destructor defined for decls */
        /* No destructor defined for decl */
        break;
      case 2:
        YYTRACE("decls ::=")
        break;
      case 3:
        YYTRACE("decl ::= pdu_decl")
        /* No destructor defined for pdu_decl */
        break;
      case 4:
        YYTRACE("decl ::= gop_decl")
        /* No destructor defined for gop_decl */
        break;
      case 5:
        YYTRACE("decl ::= gog_decl")
        /* No destructor defined for gog_decl */
        break;
      case 6:
        YYTRACE("decl ::= transform_decl")
        /* No destructor defined for transform_decl */
        break;
      case 7:
        YYTRACE("decl ::= defaults_decl")
        /* No destructor defined for defaults_decl */
        break;
      case 8:
        YYTRACE("decl ::= debug_decl")
        /* No destructor defined for debug_decl */
        break;
      case 9:
        YYTRACE("decl ::= DONE_KW SEMICOLON")
  yy_destructor(12,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 10:
        YYTRACE("debug_decl ::= DEBUG_KW OPEN_BRACE dbgfile_default dbglevel_default pdu_dbglevel_default gop_dbglevel_default gog_dbglevel_default CLOSE_BRACE SEMICOLON")
  yy_destructor(9,&yymsp[-8].minor);
  yy_destructor(42,&yymsp[-7].minor);
        /* No destructor defined for dbgfile_default */
        /* No destructor defined for dbglevel_default */
        /* No destructor defined for pdu_dbglevel_default */
        /* No destructor defined for gop_dbglevel_default */
        /* No destructor defined for gog_dbglevel_default */
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 11:
        YYTRACE("dbgfile_default ::= FILENAME_KW QUOTED SEMICOLON")
#line 266 "./mate_grammar.lemon"
{ mc->dbg_facility = fopen(yymsp[-1].minor.yy0,"w"); if (mc->dbg_facility == NULL) report_open_failure(yymsp[-1].minor.yy0,errno,TRUE); }
#line 1988 "mate_grammar.c"
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 12:
        YYTRACE("dbgfile_default ::= FILENAME_KW NAME SEMICOLON")
#line 267 "./mate_grammar.lemon"
{ mc->dbg_facility = fopen(yymsp[-1].minor.yy0,"w"); if (mc->dbg_facility == NULL) report_open_failure(yymsp[-1].minor.yy0,errno,TRUE);  }
#line 1996 "mate_grammar.c"
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 13:
        YYTRACE("dbgfile_default ::=")
        break;
      case 14:
        YYTRACE("dbglevel_default ::= LEVEL_KW INTEGER SEMICOLON")
#line 270 "./mate_grammar.lemon"
{ mc->dbg_lvl = (int) strtol(yymsp[-1].minor.yy0,NULL,10); }
#line 2007 "mate_grammar.c"
  yy_destructor(33,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 15:
        YYTRACE("dbglevel_default ::=")
        break;
      case 16:
        YYTRACE("pdu_dbglevel_default ::= PDU_KW LEVEL_KW INTEGER SEMICOLON")
#line 273 "./mate_grammar.lemon"
{ mc->dbg_pdu_lvl = (int) strtol(yymsp[-1].minor.yy0,NULL,10); }
#line 2018 "mate_grammar.c"
  yy_destructor(45,&yymsp[-3].minor);
  yy_destructor(33,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 17:
        YYTRACE("pdu_dbglevel_default ::=")
        break;
      case 18:
        YYTRACE("gop_dbglevel_default ::= GOP_KW LEVEL_KW INTEGER SEMICOLON")
#line 276 "./mate_grammar.lemon"
{ mc->dbg_gop_lvl = (int) strtol(yymsp[-1].minor.yy0,NULL,10); }
#line 2030 "mate_grammar.c"
  yy_destructor(26,&yymsp[-3].minor);
  yy_destructor(33,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 19:
        YYTRACE("gop_dbglevel_default ::=")
        break;
      case 20:
        YYTRACE("gog_dbglevel_default ::= GOG_KW LEVEL_KW INTEGER SEMICOLON")
#line 279 "./mate_grammar.lemon"
{ mc->dbg_gog_lvl = (int) strtol(yymsp[-1].minor.yy0,NULL,10); }
#line 2042 "mate_grammar.c"
  yy_destructor(25,&yymsp[-3].minor);
  yy_destructor(33,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 21:
        YYTRACE("gog_dbglevel_default ::=")
        break;
      case 22:
        YYTRACE("defaults_decl ::= DEFAULT_KW OPEN_BRACE pdu_defaults gop_defaults gog_defaults CLOSE_BRACE SEMICOLON")
  yy_destructor(10,&yymsp[-6].minor);
  yy_destructor(42,&yymsp[-5].minor);
        /* No destructor defined for pdu_defaults */
        /* No destructor defined for gop_defaults */
        /* No destructor defined for gog_defaults */
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 23:
        YYTRACE("pdu_defaults ::= PDU_KW OPEN_BRACE pdu_last_extracted_default pdu_drop_unassigned_default pdu_discard_default CLOSE_BRACE SEMICOLON")
  yy_destructor(45,&yymsp[-6].minor);
  yy_destructor(42,&yymsp[-5].minor);
        /* No destructor defined for pdu_last_extracted_default */
        /* No destructor defined for pdu_drop_unassigned_default */
        /* No destructor defined for pdu_discard_default */
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 24:
        YYTRACE("pdu_defaults ::=")
        break;
      case 25:
        YYTRACE("pdu_last_extracted_default ::= LAST_EXTRACTED_KW true_false SEMICOLON")
#line 291 "./mate_grammar.lemon"
{ mc->defaults.pdu.last_extracted = yymsp[-1].minor.yy182; }
#line 2077 "mate_grammar.c"
  yy_destructor(31,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 26:
        YYTRACE("pdu_last_extracted_default ::=")
        break;
      case 27:
        YYTRACE("pdu_drop_unassigned_default ::= DROP_UNASSIGNED_KW true_false SEMICOLON")
#line 294 "./mate_grammar.lemon"
{ mc->defaults.pdu.drop_unassigned = yymsp[-1].minor.yy182; }
#line 2088 "mate_grammar.c"
  yy_destructor(14,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 28:
        YYTRACE("pdu_drop_unassigned_default ::=")
        break;
      case 29:
        YYTRACE("pdu_discard_default ::= DISCARD_PDU_DATA_KW true_false SEMICOLON")
#line 297 "./mate_grammar.lemon"
{ mc->defaults.pdu.discard = yymsp[-1].minor.yy182; }
#line 2099 "mate_grammar.c"
  yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 30:
        YYTRACE("pdu_discard_default ::=")
        break;
      case 31:
        YYTRACE("gop_defaults ::= GOP_KW OPEN_BRACE gop_expiration_default gop_idle_timeout_default gop_lifetime_default gop_drop_unassigned_default gop_tree_mode_default gop_show_times_default CLOSE_BRACE SEMICOLON")
  yy_destructor(26,&yymsp[-9].minor);
  yy_destructor(42,&yymsp[-8].minor);
        /* No destructor defined for gop_expiration_default */
        /* No destructor defined for gop_idle_timeout_default */
        /* No destructor defined for gop_lifetime_default */
        /* No destructor defined for gop_drop_unassigned_default */
        /* No destructor defined for gop_tree_mode_default */
        /* No destructor defined for gop_show_times_default */
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 32:
        YYTRACE("gop_defaults ::=")
        break;
      case 33:
        YYTRACE("gop_expiration_default ::= EXPIRATION_KW time_value SEMICOLON")
#line 303 "./mate_grammar.lemon"
{ mc->defaults.gop.expiration = yymsp[-1].minor.yy255; }
#line 2126 "mate_grammar.c"
  yy_destructor(16,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 34:
        YYTRACE("gop_expiration_default ::=")
        break;
      case 35:
        YYTRACE("gop_idle_timeout_default ::= IDLE_TIMEOUT_KW time_value SEMICOLON")
#line 306 "./mate_grammar.lemon"
{ mc->defaults.gop.idle_timeout = yymsp[-1].minor.yy255; }
#line 2137 "mate_grammar.c"
  yy_destructor(28,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 36:
        YYTRACE("gop_idle_timeout_default ::=")
        break;
      case 37:
        YYTRACE("gop_lifetime_default ::= LIFETIME_KW time_value SEMICOLON")
#line 309 "./mate_grammar.lemon"
{ mc->defaults.gop.lifetime = yymsp[-1].minor.yy255; }
#line 2148 "mate_grammar.c"
  yy_destructor(34,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 38:
        YYTRACE("gop_lifetime_default ::=")
        break;
      case 39:
        YYTRACE("gop_drop_unassigned_default ::= DROP_UNASSIGNED_KW true_false SEMICOLON")
#line 312 "./mate_grammar.lemon"
{ mc->defaults.gop.drop_unassigned = yymsp[-1].minor.yy182; }
#line 2159 "mate_grammar.c"
  yy_destructor(14,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 40:
        YYTRACE("gop_drop_unassigned_default ::=")
        break;
      case 41:
        YYTRACE("gop_tree_mode_default ::= SHOW_TREE_KW gop_tree_mode SEMICOLON")
#line 315 "./mate_grammar.lemon"
{ mc->defaults.gop.pdu_tree_mode = yymsp[-1].minor.yy256; }
#line 2170 "mate_grammar.c"
  yy_destructor(54,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 42:
        YYTRACE("gop_tree_mode_default ::=")
        break;
      case 43:
        YYTRACE("gop_show_times_default ::= SHOW_TIMES_KW true_false SEMICOLON")
#line 318 "./mate_grammar.lemon"
{ mc->defaults.gop.show_times = yymsp[-1].minor.yy182; }
#line 2181 "mate_grammar.c"
  yy_destructor(53,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 44:
        YYTRACE("gop_show_times_default ::=")
        break;
      case 45:
        YYTRACE("gog_defaults ::= GOG_KW OPEN_BRACE gog_expiration_default gop_tree_mode_default gog_goptree_default CLOSE_BRACE SEMICOLON")
  yy_destructor(25,&yymsp[-6].minor);
  yy_destructor(42,&yymsp[-5].minor);
        /* No destructor defined for gog_expiration_default */
        /* No destructor defined for gop_tree_mode_default */
        /* No destructor defined for gog_goptree_default */
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 46:
        YYTRACE("gog_defaults ::=")
        break;
      case 47:
        YYTRACE("gog_expiration_default ::= EXPIRATION_KW time_value SEMICOLON")
#line 324 "./mate_grammar.lemon"
{ mc->defaults.gop.expiration = yymsp[-1].minor.yy255; }
#line 2205 "mate_grammar.c"
  yy_destructor(16,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 48:
        YYTRACE("gog_expiration_default ::=")
        break;
      case 49:
        YYTRACE("gog_goptree_default ::= GOP_TREE_KW gop_tree_type SEMICOLON")
#line 327 "./mate_grammar.lemon"
{ mc->defaults.gog.gop_tree_mode = yymsp[-1].minor.yy256; }
#line 2216 "mate_grammar.c"
  yy_destructor(27,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 50:
        YYTRACE("gog_goptree_default ::=")
        break;
      case 51:
        YYTRACE("transform_decl ::= TRANSFORM_KW NAME transform_body SEMICOLON")
#line 334 "./mate_grammar.lemon"
{
	AVPL_Transf* c;

	if ( g_hash_table_lookup(mc->transfs,yymsp[-2].minor.yy0) ) {
		configuration_error(mc,"yygotominor.yy145 transformation called '%s' exists already",yymsp[-2].minor.yy0);
	}

	for ( c = yymsp[-1].minor.yy145; c; c = c->next )
		c->name = g_strdup(yymsp[-2].minor.yy0);
	
	g_hash_table_insert(mc->transfs,yymsp[-1].minor.yy145->name,yymsp[-1].minor.yy145);
	
	yygotominor.yy145 = NULL;
}
#line 2240 "mate_grammar.c"
  yy_destructor(59,&yymsp[-3].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 52:
        YYTRACE("transform_body ::= OPEN_BRACE transform_statements CLOSE_BRACE")
#line 349 "./mate_grammar.lemon"
{ yygotominor.yy145 = yymsp[-1].minor.yy145; }
#line 2248 "mate_grammar.c"
  yy_destructor(42,&yymsp[-2].minor);
  yy_destructor(4,&yymsp[0].minor);
        break;
      case 53:
        YYTRACE("transform_statements ::= transform_statements transform_statement")
#line 351 "./mate_grammar.lemon"
{
    AVPL_Transf* c;
	
	for ( c = yymsp[-1].minor.yy145; c->next; c = c->next ) ;
	c->next = yymsp[0].minor.yy145;
	yygotominor.yy145 = yymsp[-1].minor.yy145;
}
#line 2262 "mate_grammar.c"
        break;
      case 54:
        YYTRACE("transform_statements ::= transform_statement")
#line 359 "./mate_grammar.lemon"
{ yygotominor.yy145 = yymsp[0].minor.yy145; }
#line 2268 "mate_grammar.c"
        break;
      case 55:
        YYTRACE("transform_statement ::= transform_match transform_action SEMICOLON")
#line 361 "./mate_grammar.lemon"
{
	yygotominor.yy145 = new_transform_elem(yymsp[-2].minor.yy146->avpl,yymsp[-1].minor.yy85->avpl,yymsp[-2].minor.yy146->match_mode,yymsp[-1].minor.yy85->replace_mode);
}
#line 2276 "mate_grammar.c"
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 56:
        YYTRACE("transform_match ::= MATCH_KW match_mode avpl")
#line 365 "./mate_grammar.lemon"
{
    yygotominor.yy146 = g_malloc(sizeof(transf_match_t));
    yygotominor.yy146->match_mode = yymsp[-1].minor.yy156;
    yygotominor.yy146->avpl = yymsp[0].minor.yy70;
}
#line 2287 "mate_grammar.c"
  yy_destructor(36,&yymsp[-2].minor);
        break;
      case 57:
        YYTRACE("transform_match ::=")
#line 371 "./mate_grammar.lemon"
{
    yygotominor.yy146 = g_malloc(sizeof(transf_match_t));
    yygotominor.yy146->match_mode = AVPL_STRICT;
    yygotominor.yy146->avpl = new_avpl("");

}
#line 2299 "mate_grammar.c"
        break;
      case 58:
        YYTRACE("transform_action ::=")
#line 378 "./mate_grammar.lemon"
{
    yygotominor.yy85 = g_malloc(sizeof(transf_action_t));
    yygotominor.yy85->replace_mode = AVPL_INSERT;
    yygotominor.yy85->avpl = new_avpl("");
}
#line 2309 "mate_grammar.c"
        break;
      case 59:
        YYTRACE("transform_action ::= action_mode avpl")
#line 383 "./mate_grammar.lemon"
{
    yygotominor.yy85 = g_malloc(sizeof(transf_action_t));
    yygotominor.yy85->replace_mode = yymsp[-1].minor.yy13;
    yygotominor.yy85->avpl = yymsp[0].minor.yy70;
}
#line 2319 "mate_grammar.c"
        break;
      case 60:
        YYTRACE("match_mode ::=")
#line 389 "./mate_grammar.lemon"
{ yygotominor.yy156 = AVPL_STRICT; }
#line 2325 "mate_grammar.c"
        break;
      case 61:
        YYTRACE("match_mode ::= STRICT_KW")
#line 390 "./mate_grammar.lemon"
{ yygotominor.yy156 = AVPL_STRICT; }
#line 2331 "mate_grammar.c"
  yy_destructor(58,&yymsp[0].minor);
        break;
      case 62:
        YYTRACE("match_mode ::= EVERY_KW")
#line 391 "./mate_grammar.lemon"
{ yygotominor.yy156 = AVPL_EVERY; }
#line 2338 "mate_grammar.c"
  yy_destructor(15,&yymsp[0].minor);
        break;
      case 63:
        YYTRACE("match_mode ::= LOOSE_KW")
#line 392 "./mate_grammar.lemon"
{ yygotominor.yy156 = AVPL_LOOSE; }
#line 2345 "mate_grammar.c"
  yy_destructor(35,&yymsp[0].minor);
        break;
      case 64:
        YYTRACE("action_mode ::= REPLACE_KW")
#line 394 "./mate_grammar.lemon"
{ yygotominor.yy13 = AVPL_REPLACE; }
#line 2352 "mate_grammar.c"
  yy_destructor(51,&yymsp[0].minor);
        break;
      case 65:
        YYTRACE("action_mode ::= INSERT_KW")
#line 395 "./mate_grammar.lemon"
{ yygotominor.yy13 = AVPL_INSERT; }
#line 2359 "mate_grammar.c"
  yy_destructor(29,&yymsp[0].minor);
        break;
      case 66:
        YYTRACE("action_mode ::=")
#line 396 "./mate_grammar.lemon"
{ yygotominor.yy13 = AVPL_INSERT; }
#line 2366 "mate_grammar.c"
        break;
      case 67:
        YYTRACE("pdu_decl ::= PDU_KW NAME PROTO_KW field TRANSPORT_KW proto_stack OPEN_BRACE payload_statement extraction_statements transform_list_statement criteria_statement pdu_drop_unassigned_statement discard_pdu_data_statement last_extracted_statement CLOSE_BRACE SEMICOLON")
#line 412 "./mate_grammar.lemon"
{
    
	mate_cfg_pdu* cfg  = new_pducfg(yymsp[-14].minor.yy0);
	extraction_t *extraction, *next_extraction;
	GPtrArray* transport_stack = g_ptr_array_new();
	int i;
	
	if (! cfg ) configuration_error(mc,"could not create Pdu %s.",yymsp[-14].minor.yy0);

	cfg->hfid_proto = yymsp[-12].minor.yy210->id;

	cfg->last_extracted = yymsp[-2].minor.yy182;
	cfg->discard = yymsp[-3].minor.yy182;
	cfg->drop_unassigned = yymsp[-4].minor.yy182;
	
	g_string_sprintfa(mc->protos_filter,"||%s",yymsp[-12].minor.yy210->abbrev);

	/* flip the transport_stack */
	for (i = yymsp[-10].minor.yy9->len - 1; yymsp[-10].minor.yy9->len; i--) {
		g_ptr_array_add(transport_stack,g_ptr_array_remove_index(yymsp[-10].minor.yy9,i));
	}
	
	g_ptr_array_free(yymsp[-10].minor.yy9,FALSE);
	
	cfg->transport_ranges = transport_stack;
	cfg->payload_ranges = yymsp[-8].minor.yy9;
	
	if (yymsp[-5].minor.yy199) {
		cfg->criterium = yymsp[-5].minor.yy199->criterium_avpl;
		cfg->criterium_match_mode = yymsp[-5].minor.yy199->criterium_match_mode;
		cfg->criterium_accept_mode = yymsp[-5].minor.yy199->criterium_accept_mode;
	}
	
	cfg->transforms = yymsp[-6].minor.yy9;
	
	for (extraction = yymsp[-7].minor.yy179; extraction; extraction = next_extraction) {
		next_extraction = extraction->next;
		
		if ( ! add_hfid(extraction->hfi, extraction->as, cfg->hfids_attr) ) {
			configuration_error(mc,"MATE: failed to create extraction rule '%s'",extraction->as);
		}
		
		g_free(extraction);
	}
}
#line 2416 "mate_grammar.c"
  yy_destructor(45,&yymsp[-15].minor);
  yy_destructor(48,&yymsp[-13].minor);
  yy_destructor(60,&yymsp[-11].minor);
  yy_destructor(42,&yymsp[-9].minor);
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 68:
        YYTRACE("payload_statement ::=")
#line 458 "./mate_grammar.lemon"
{ yygotominor.yy9 = NULL; }
#line 2428 "mate_grammar.c"
        break;
      case 69:
        YYTRACE("payload_statement ::= PAYLOAD_KW proto_stack SEMICOLON")
#line 459 "./mate_grammar.lemon"
{ yygotominor.yy9 = yymsp[-1].minor.yy9; }
#line 2434 "mate_grammar.c"
  yy_destructor(44,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 70:
        YYTRACE("criteria_statement ::=")
#line 461 "./mate_grammar.lemon"
{ yygotominor.yy199 = NULL; }
#line 2442 "mate_grammar.c"
        break;
      case 71:
        YYTRACE("criteria_statement ::= CRITERIA_KW accept_mode match_mode avpl SEMICOLON")
#line 462 "./mate_grammar.lemon"
{
	yygotominor.yy199 = g_malloc(sizeof(pdu_criteria_t));
	yygotominor.yy199->criterium_avpl = yymsp[-1].minor.yy70;
	yygotominor.yy199->criterium_match_mode = yymsp[-2].minor.yy156;
	yygotominor.yy199->criterium_accept_mode = yymsp[-3].minor.yy8;
}
#line 2453 "mate_grammar.c"
  yy_destructor(8,&yymsp[-4].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 72:
        YYTRACE("accept_mode ::=")
#line 469 "./mate_grammar.lemon"
{ yygotominor.yy8 = ACCEPT_MODE; }
#line 2461 "mate_grammar.c"
        break;
      case 73:
        YYTRACE("accept_mode ::= ACCEPT_KW")
#line 470 "./mate_grammar.lemon"
{ yygotominor.yy8 = ACCEPT_MODE; }
#line 2467 "mate_grammar.c"
  yy_destructor(1,&yymsp[0].minor);
        break;
      case 74:
        YYTRACE("accept_mode ::= REJECT_KW")
#line 471 "./mate_grammar.lemon"
{ yygotominor.yy8 = REJECT_MODE; }
#line 2474 "mate_grammar.c"
  yy_destructor(50,&yymsp[0].minor);
        break;
      case 75:
        YYTRACE("extraction_statements ::= extraction_statements extraction_statement")
#line 473 "./mate_grammar.lemon"
{ yygotominor.yy179 = yymsp[-1].minor.yy179; yygotominor.yy179->last = yygotominor.yy179->last->next = yymsp[0].minor.yy179; }
#line 2481 "mate_grammar.c"
        break;
      case 76:
        YYTRACE("extraction_statements ::= extraction_statement")
#line 474 "./mate_grammar.lemon"
{ yygotominor.yy179 = yymsp[0].minor.yy179; yygotominor.yy179->last = yygotominor.yy179; }
#line 2487 "mate_grammar.c"
        break;
      case 77:
        YYTRACE("extraction_statement ::= EXTRACT_KW NAME FROM_KW field SEMICOLON")
#line 476 "./mate_grammar.lemon"
{
	yygotominor.yy179 = g_malloc(sizeof(extraction_t));
	yygotominor.yy179->as = yymsp[-3].minor.yy0;
	yygotominor.yy179->hfi = yymsp[-1].minor.yy210;
	yygotominor.yy179->next = yygotominor.yy179->last = NULL;
}
#line 2498 "mate_grammar.c"
  yy_destructor(17,&yymsp[-4].minor);
  yy_destructor(23,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 78:
        YYTRACE("pdu_drop_unassigned_statement ::= DROP_UNASSIGNED_KW true_false SEMICOLON")
#line 484 "./mate_grammar.lemon"
{ yygotominor.yy182 = yymsp[-1].minor.yy182; }
#line 2507 "mate_grammar.c"
  yy_destructor(14,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 79:
        YYTRACE("pdu_drop_unassigned_statement ::=")
#line 485 "./mate_grammar.lemon"
{ yygotominor.yy182 =  mc->defaults.pdu.drop_unassigned; }
#line 2515 "mate_grammar.c"
        break;
      case 80:
        YYTRACE("discard_pdu_data_statement ::= DISCARD_PDU_DATA_KW true_false SEMICOLON")
#line 487 "./mate_grammar.lemon"
{ yygotominor.yy182 = yymsp[-1].minor.yy182; }
#line 2521 "mate_grammar.c"
  yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 81:
        YYTRACE("discard_pdu_data_statement ::=")
#line 488 "./mate_grammar.lemon"
{ yygotominor.yy182 =  mc->defaults.pdu.discard; }
#line 2529 "mate_grammar.c"
        break;
      case 82:
        YYTRACE("last_extracted_statement ::= LAST_PDU_KW true_false SEMICOLON")
#line 490 "./mate_grammar.lemon"
{ yygotominor.yy182 = yymsp[-1].minor.yy182; }
#line 2535 "mate_grammar.c"
  yy_destructor(32,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 83:
        YYTRACE("last_extracted_statement ::=")
#line 491 "./mate_grammar.lemon"
{ yygotominor.yy182 = mc->defaults.pdu.last_extracted; }
#line 2543 "mate_grammar.c"
        break;
      case 84:
        YYTRACE("proto_stack ::= proto_stack SLASH field")
#line 493 "./mate_grammar.lemon"
{
	int* hfidp = g_malloc(sizeof(int));

	g_string_sprintfa(mc->fields_filter,"||%s",yymsp[0].minor.yy210->abbrev);
	
	*hfidp = yymsp[0].minor.yy210->id;
	g_ptr_array_add(yymsp[-2].minor.yy9,hfidp);
	yygotominor.yy9 = yymsp[-2].minor.yy9;
}
#line 2557 "mate_grammar.c"
  yy_destructor(55,&yymsp[-1].minor);
        break;
      case 85:
        YYTRACE("proto_stack ::= field")
#line 503 "./mate_grammar.lemon"
{
	int* hfidp = g_malloc(sizeof(int));
	*hfidp = yymsp[0].minor.yy210->id;
	
	g_string_sprintfa(mc->fields_filter,"||%s",yymsp[0].minor.yy210->abbrev);

	yygotominor.yy9 = g_ptr_array_new();
	g_ptr_array_add(yygotominor.yy9,hfidp);
}
#line 2572 "mate_grammar.c"
        break;
      case 86:
        YYTRACE("field ::= NAME")
#line 513 "./mate_grammar.lemon"
{
	yygotominor.yy210 = proto_registrar_get_byname(yymsp[0].minor.yy0);
}
#line 2580 "mate_grammar.c"
        break;
      case 87:
        YYTRACE("gop_decl ::= GOP_KW NAME ON_KW pdu_name MATCH_KW avpl OPEN_BRACE gop_start_statement gop_stop_statement extra_statement transform_list_statement gop_expiration_statement idle_timeout_statement lifetime_statement gop_drop_unassigned_statement show_goptree_statement show_times_statement CLOSE_BRACE SEMICOLON")
#line 531 "./mate_grammar.lemon"
{
	mate_cfg_gop* cfg;
	
	if (g_hash_table_lookup(mc->gopcfgs,yymsp[-17].minor.yy0)) configuration_error(mc,"yygotominor.yy0 Gop Named '%s' exists already.",yymsp[-17].minor.yy0);
	if (g_hash_table_lookup(mc->gops_by_pduname,yymsp[-15].minor.yy212) ) configuration_error(mc,"Gop for Pdu '%s' exists already",yymsp[-15].minor.yy212);

	cfg = new_gopcfg(yymsp[-17].minor.yy0);
	g_hash_table_insert(mc->gops_by_pduname,yymsp[-15].minor.yy212,cfg);
	g_hash_table_insert(mc->gopcfgs,cfg->name,cfg);
    
	cfg->on_pdu = yymsp[-15].minor.yy212;
	cfg->key = yymsp[-13].minor.yy70;
    cfg->drop_unassigned = yymsp[-4].minor.yy182;
    cfg->show_times = yymsp[-2].minor.yy182;
    cfg->pdu_tree_mode = yymsp[-3].minor.yy256;
    cfg->expiration = yymsp[-7].minor.yy255;
    cfg->idle_timeout = yymsp[-6].minor.yy255;
    cfg->lifetime = yymsp[-5].minor.yy255;
    cfg->start = yymsp[-11].minor.yy70;
    cfg->stop = yymsp[-10].minor.yy70;
    cfg->transforms = yymsp[-8].minor.yy9;
    
    merge_avpl(cfg->extra,yymsp[-9].minor.yy70,TRUE);
    delete_avpl(yymsp[-9].minor.yy70,TRUE);
}
#line 2610 "mate_grammar.c"
  yy_destructor(26,&yymsp[-18].minor);
  yy_destructor(41,&yymsp[-16].minor);
  yy_destructor(36,&yymsp[-14].minor);
  yy_destructor(42,&yymsp[-12].minor);
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 88:
        YYTRACE("gop_drop_unassigned_statement ::= DROP_UNASSIGNED_KW true_false SEMICOLON")
#line 557 "./mate_grammar.lemon"
{ yygotominor.yy182 = yymsp[-1].minor.yy182; }
#line 2622 "mate_grammar.c"
  yy_destructor(14,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 89:
        YYTRACE("gop_drop_unassigned_statement ::=")
#line 558 "./mate_grammar.lemon"
{ yygotominor.yy182 =  mc->defaults.gop.drop_unassigned; }
#line 2630 "mate_grammar.c"
        break;
      case 90:
        YYTRACE("gop_start_statement ::= START_KW avpl SEMICOLON")
#line 560 "./mate_grammar.lemon"
{ yygotominor.yy70 = yymsp[-1].minor.yy70; }
#line 2636 "mate_grammar.c"
  yy_destructor(56,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 91:
        YYTRACE("gop_start_statement ::=")
#line 561 "./mate_grammar.lemon"
{ yygotominor.yy70 = NULL; }
#line 2644 "mate_grammar.c"
        break;
      case 92:
        YYTRACE("gop_stop_statement ::= STOP_KW avpl SEMICOLON")
#line 563 "./mate_grammar.lemon"
{ yygotominor.yy70 = yymsp[-1].minor.yy70; }
#line 2650 "mate_grammar.c"
  yy_destructor(57,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 93:
        YYTRACE("gop_stop_statement ::=")
#line 564 "./mate_grammar.lemon"
{ yygotominor.yy70 = NULL; }
#line 2658 "mate_grammar.c"
        break;
      case 94:
        YYTRACE("show_goptree_statement ::= SHOW_TREE_KW gop_tree_mode SEMICOLON")
#line 566 "./mate_grammar.lemon"
{ yygotominor.yy256 = yymsp[-1].minor.yy256; }
#line 2664 "mate_grammar.c"
  yy_destructor(54,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 95:
        YYTRACE("show_goptree_statement ::=")
#line 567 "./mate_grammar.lemon"
{ yygotominor.yy256 = mc->defaults.gop.pdu_tree_mode; }
#line 2672 "mate_grammar.c"
        break;
      case 96:
        YYTRACE("show_times_statement ::= SHOW_TIMES_KW true_false SEMICOLON")
#line 569 "./mate_grammar.lemon"
{ yygotominor.yy182 = yymsp[-1].minor.yy182; }
#line 2678 "mate_grammar.c"
  yy_destructor(53,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 97:
        YYTRACE("show_times_statement ::=")
#line 570 "./mate_grammar.lemon"
{ yygotominor.yy182 = mc->defaults.gop.show_times; }
#line 2686 "mate_grammar.c"
        break;
      case 98:
        YYTRACE("gop_expiration_statement ::= EXPIRATION_KW time_value SEMICOLON")
#line 572 "./mate_grammar.lemon"
{ yygotominor.yy255 = yymsp[-1].minor.yy255; }
#line 2692 "mate_grammar.c"
  yy_destructor(16,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 99:
        YYTRACE("gop_expiration_statement ::=")
#line 573 "./mate_grammar.lemon"
{ yygotominor.yy255 = mc->defaults.gop.lifetime; }
#line 2700 "mate_grammar.c"
        break;
      case 100:
        YYTRACE("idle_timeout_statement ::= IDLE_TIMEOUT_KW time_value SEMICOLON")
#line 575 "./mate_grammar.lemon"
{ yygotominor.yy255 = yymsp[-1].minor.yy255; }
#line 2706 "mate_grammar.c"
  yy_destructor(28,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 101:
        YYTRACE("idle_timeout_statement ::=")
#line 576 "./mate_grammar.lemon"
{ yygotominor.yy255 = mc->defaults.gop.lifetime; }
#line 2714 "mate_grammar.c"
        break;
      case 102:
        YYTRACE("lifetime_statement ::= LIFETIME_KW time_value SEMICOLON")
#line 578 "./mate_grammar.lemon"
{ yygotominor.yy255 = yymsp[-1].minor.yy255; }
#line 2720 "mate_grammar.c"
  yy_destructor(34,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 103:
        YYTRACE("lifetime_statement ::=")
#line 579 "./mate_grammar.lemon"
{ yygotominor.yy255 = mc->defaults.gop.lifetime; }
#line 2728 "mate_grammar.c"
        break;
      case 104:
        YYTRACE("gop_tree_mode ::= NO_TREE_KW")
#line 581 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_NO_TREE; }
#line 2734 "mate_grammar.c"
  yy_destructor(39,&yymsp[0].minor);
        break;
      case 105:
        YYTRACE("gop_tree_mode ::= PDU_TREE_KW")
#line 582 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_PDU_TREE; }
#line 2741 "mate_grammar.c"
  yy_destructor(46,&yymsp[0].minor);
        break;
      case 106:
        YYTRACE("gop_tree_mode ::= FRAME_TREE_KW")
#line 583 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_FRAME_TREE; }
#line 2748 "mate_grammar.c"
  yy_destructor(22,&yymsp[0].minor);
        break;
      case 107:
        YYTRACE("gop_tree_mode ::= BASIC_TREE_KW")
#line 584 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_BASIC_PDU_TREE; }
#line 2755 "mate_grammar.c"
  yy_destructor(3,&yymsp[0].minor);
        break;
      case 108:
        YYTRACE("true_false ::= TRUE_KW")
#line 586 "./mate_grammar.lemon"
{ yygotominor.yy182 = TRUE; }
#line 2762 "mate_grammar.c"
  yy_destructor(61,&yymsp[0].minor);
        break;
      case 109:
        YYTRACE("true_false ::= FALSE_KW")
#line 587 "./mate_grammar.lemon"
{ yygotominor.yy182 = FALSE; }
#line 2769 "mate_grammar.c"
  yy_destructor(19,&yymsp[0].minor);
        break;
      case 110:
        YYTRACE("pdu_name ::= NAME")
#line 589 "./mate_grammar.lemon"
{
	mate_cfg_pdu* c;
	if (( c =  g_hash_table_lookup(mc->pducfgs,yymsp[0].minor.yy0) )) {
		yygotominor.yy212 = c->name;
	} else {
		configuration_error(mc,"No such Pdu: '%s'",yymsp[0].minor.yy0);
	}
}
#line 2783 "mate_grammar.c"
        break;
      case 111:
        YYTRACE("time_value ::= FLOATING")
#line 599 "./mate_grammar.lemon"
{
	yygotominor.yy255 = (float) strtod(yymsp[0].minor.yy0,NULL);
}
#line 2791 "mate_grammar.c"
        break;
      case 112:
        YYTRACE("time_value ::= INTEGER")
#line 603 "./mate_grammar.lemon"
{
	yygotominor.yy255 = (float) strtod(yymsp[0].minor.yy0,NULL);
}
#line 2799 "mate_grammar.c"
        break;
      case 113:
        YYTRACE("gog_decl ::= GOG_KW NAME OPEN_BRACE gog_key_statements extra_statement transform_list_statement gog_expiration_statement gog_goptree_statement CLOSE_BRACE SEMICOLON")
#line 616 "./mate_grammar.lemon"
{
	mate_cfg_gog* cfg = NULL;
	
	if ( g_hash_table_lookup(mc->gogcfgs,yymsp[-8].minor.yy0) ) {
		configuration_error(mc,"Gog '%s' exists already ",yymsp[-8].minor.yy0);
	}
	
	cfg = new_gogcfg(yymsp[-8].minor.yy0);

	cfg->expiration = yymsp[-3].minor.yy255;
	cfg->gop_tree_mode = yymsp[-2].minor.yy256;
	cfg->transforms = yymsp[-4].minor.yy9;
	cfg->keys = yymsp[-6].minor.yy77;
	
    merge_avpl(cfg->extra,yymsp[-5].minor.yy70,TRUE);
    delete_avpl(yymsp[-5].minor.yy70,TRUE);
}
#line 2821 "mate_grammar.c"
  yy_destructor(25,&yymsp[-9].minor);
  yy_destructor(42,&yymsp[-7].minor);
  yy_destructor(4,&yymsp[-1].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 114:
        YYTRACE("gog_goptree_statement ::= GOP_TREE_KW gop_tree_type SEMICOLON")
#line 634 "./mate_grammar.lemon"
{ yygotominor.yy256 = yymsp[-1].minor.yy256; }
#line 2831 "mate_grammar.c"
  yy_destructor(27,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 115:
        YYTRACE("gog_goptree_statement ::=")
#line 635 "./mate_grammar.lemon"
{ yygotominor.yy256 = mc->defaults.gog.gop_tree_mode; }
#line 2839 "mate_grammar.c"
        break;
      case 116:
        YYTRACE("gog_expiration_statement ::= EXPIRATION_KW time_value SEMICOLON")
#line 637 "./mate_grammar.lemon"
{ yygotominor.yy255 = yymsp[-1].minor.yy255; }
#line 2845 "mate_grammar.c"
  yy_destructor(16,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 117:
        YYTRACE("gog_expiration_statement ::=")
#line 638 "./mate_grammar.lemon"
{ yygotominor.yy255 = mc->defaults.gog.expiration; }
#line 2853 "mate_grammar.c"
        break;
      case 118:
        YYTRACE("gop_tree_type ::= NULL_TREE_KW")
#line 640 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_NULL_TREE; }
#line 2859 "mate_grammar.c"
  yy_destructor(40,&yymsp[0].minor);
        break;
      case 119:
        YYTRACE("gop_tree_type ::= FULL_TREE_KW")
#line 641 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_FULL_TREE; }
#line 2866 "mate_grammar.c"
  yy_destructor(24,&yymsp[0].minor);
        break;
      case 120:
        YYTRACE("gop_tree_type ::= BASIC_TREE_KW")
#line 642 "./mate_grammar.lemon"
{ yygotominor.yy256 = GOP_BASIC_TREE; }
#line 2873 "mate_grammar.c"
  yy_destructor(3,&yymsp[0].minor);
        break;
      case 121:
        YYTRACE("gog_key_statements ::= gog_key_statements gog_key_statement")
#line 644 "./mate_grammar.lemon"
{
	loal_append(yymsp[-1].minor.yy77,yymsp[0].minor.yy70);
	yygotominor.yy77 = yymsp[-1].minor.yy77;
}
#line 2883 "mate_grammar.c"
        break;
      case 122:
        YYTRACE("gog_key_statements ::= gog_key_statement")
#line 649 "./mate_grammar.lemon"
{
	yygotominor.yy77 = new_loal("");
	loal_append(yygotominor.yy77,yymsp[0].minor.yy70);
}
#line 2892 "mate_grammar.c"
        break;
      case 123:
        YYTRACE("gog_key_statement ::= MEMBER_KW gop_name avpl SEMICOLON")
#line 655 "./mate_grammar.lemon"
{
	rename_avpl(yymsp[-1].minor.yy70,yymsp[-2].minor.yy212);
	yygotominor.yy70 = yymsp[-1].minor.yy70;
}
#line 2901 "mate_grammar.c"
  yy_destructor(37,&yymsp[-3].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 124:
        YYTRACE("gop_name ::= NAME")
#line 660 "./mate_grammar.lemon"
{
	mate_cfg_gop* c;
	if (( c = g_hash_table_lookup(mc->gopcfgs,yymsp[0].minor.yy0) )) {
		yygotominor.yy212 = c->name;
	} else {
		configuration_error(mc,"No Gop called '%s' has been already declared",yymsp[0].minor.yy0);
	}
}
#line 2916 "mate_grammar.c"
        break;
      case 125:
        YYTRACE("extra_statement ::= EXTRA_KW avpl SEMICOLON")
#line 672 "./mate_grammar.lemon"
{ yygotominor.yy70 = yymsp[-1].minor.yy70; }
#line 2922 "mate_grammar.c"
  yy_destructor(18,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 126:
        YYTRACE("extra_statement ::=")
#line 673 "./mate_grammar.lemon"
{ yygotominor.yy70 = new_avpl(""); }
#line 2930 "mate_grammar.c"
        break;
      case 127:
        YYTRACE("transform_list_statement ::= TRANSFORM_KW transform_list SEMICOLON")
#line 675 "./mate_grammar.lemon"
{ yygotominor.yy9 = yymsp[-1].minor.yy9; }
#line 2936 "mate_grammar.c"
  yy_destructor(59,&yymsp[-2].minor);
  yy_destructor(52,&yymsp[0].minor);
        break;
      case 128:
        YYTRACE("transform_list_statement ::=")
#line 676 "./mate_grammar.lemon"
{ yygotominor.yy9 = g_ptr_array_new(); }
#line 2944 "mate_grammar.c"
        break;
      case 129:
        YYTRACE("transform_list ::= transform_list COMMA transform")
#line 678 "./mate_grammar.lemon"
{ 
	yygotominor.yy9 = yymsp[-2].minor.yy9;
	g_ptr_array_add(yymsp[-2].minor.yy9,yymsp[0].minor.yy145);
}
#line 2953 "mate_grammar.c"
  yy_destructor(7,&yymsp[-1].minor);
        break;
      case 130:
        YYTRACE("transform_list ::= transform")
#line 683 "./mate_grammar.lemon"
{
	yygotominor.yy9 = g_ptr_array_new();
	g_ptr_array_add(yygotominor.yy9,yymsp[0].minor.yy145);
}
#line 2963 "mate_grammar.c"
        break;
      case 131:
        YYTRACE("transform ::= NAME")
#line 688 "./mate_grammar.lemon"
{
	AVPL_Transf* t;
	
	if (( t = g_hash_table_lookup(mc->transfs,yymsp[0].minor.yy0) )) {
		yygotominor.yy145 = t;
	} else {
		configuration_error(mc,"There's no such Transformation: %s",yymsp[0].minor.yy0);
	}	
}
#line 2977 "mate_grammar.c"
        break;
      case 132:
        YYTRACE("avpl ::= OPEN_PARENS avps CLOSE_PARENS")
#line 698 "./mate_grammar.lemon"
{ yygotominor.yy70 = yymsp[-1].minor.yy70; }
#line 2983 "mate_grammar.c"
  yy_destructor(43,&yymsp[-2].minor);
  yy_destructor(5,&yymsp[0].minor);
        break;
      case 133:
        YYTRACE("avpl ::= OPEN_PARENS CLOSE_PARENS")
#line 699 "./mate_grammar.lemon"
{ yygotominor.yy70 = new_avpl(""); }
#line 2991 "mate_grammar.c"
  yy_destructor(43,&yymsp[-1].minor);
  yy_destructor(5,&yymsp[0].minor);
        break;
      case 134:
        YYTRACE("avps ::= avps COMMA avp")
#line 701 "./mate_grammar.lemon"
{ yygotominor.yy70 = yymsp[-2].minor.yy70; if ( ! insert_avp(yymsp[-2].minor.yy70,yymsp[0].minor.yy226) ) delete_avp(yymsp[0].minor.yy226); }
#line 2999 "mate_grammar.c"
  yy_destructor(7,&yymsp[-1].minor);
        break;
      case 135:
        YYTRACE("avps ::= avp")
#line 702 "./mate_grammar.lemon"
{ yygotominor.yy70 = new_avpl(""); if ( ! insert_avp(yygotominor.yy70,yymsp[0].minor.yy226) ) delete_avp(yymsp[0].minor.yy226); }
#line 3006 "mate_grammar.c"
        break;
      case 136:
        YYTRACE("avp ::= NAME AVP_OPERATOR value")
#line 704 "./mate_grammar.lemon"
{ yygotominor.yy226 = new_avp(yymsp[-2].minor.yy0,yymsp[0].minor.yy212,*yymsp[-1].minor.yy0); }
#line 3012 "mate_grammar.c"
        break;
      case 137:
        YYTRACE("avp ::= NAME")
#line 705 "./mate_grammar.lemon"
{ yygotominor.yy226 = new_avp(yymsp[0].minor.yy0,"",'?'); }
#line 3018 "mate_grammar.c"
        break;
      case 138:
        YYTRACE("avp ::= NAME OPEN_BRACE avp_oneoff CLOSE_BRACE")
#line 706 "./mate_grammar.lemon"
{ yygotominor.yy226 = new_avp(yymsp[-3].minor.yy0,yymsp[-1].minor.yy212,'|'); }
#line 3024 "mate_grammar.c"
  yy_destructor(42,&yymsp[-2].minor);
  yy_destructor(4,&yymsp[0].minor);
        break;
      case 139:
        YYTRACE("avp_oneoff ::= avp_oneoff PIPE value")
#line 708 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup_printf("%s|%s",yymsp[-2].minor.yy212,yymsp[0].minor.yy212); }
#line 3032 "mate_grammar.c"
  yy_destructor(47,&yymsp[-1].minor);
        break;
      case 140:
        YYTRACE("avp_oneoff ::= value")
#line 709 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy212); }
#line 3039 "mate_grammar.c"
        break;
      case 141:
        YYTRACE("value ::= QUOTED")
#line 711 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
#line 3045 "mate_grammar.c"
        break;
      case 142:
        YYTRACE("value ::= NAME")
#line 712 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
#line 3051 "mate_grammar.c"
        break;
      case 143:
        YYTRACE("value ::= FLOATING")
#line 713 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
#line 3057 "mate_grammar.c"
        break;
      case 144:
        YYTRACE("value ::= INTEGER")
#line 714 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
#line 3063 "mate_grammar.c"
        break;
      case 145:
        YYTRACE("value ::= DOTED_IP")
#line 715 "./mate_grammar.lemon"
{ yygotominor.yy212 = g_strdup(yymsp[0].minor.yy0); }
#line 3069 "mate_grammar.c"
        break;
      case 146:
        YYTRACE("value ::= COLONIZED")
#line 716 "./mate_grammar.lemon"
{ yygotominor.yy212 = recolonize(mc,yymsp[0].minor.yy0); }
#line 3075 "mate_grammar.c"
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->idx -= yysize;
  yypParser->top -= yysize;
  yyact = yy_find_parser_action(yypParser,yygoto);
  if( yyact < YYNSTATE ){
    yy_shift(yypParser,yyact,yygoto,&yygotominor);
  }else if( yyact == YYNSTATE + YYNRULE + 1 ){
    yy_accept(yypParser MateParserARGDECL);
  }
}

/*
** The following code executes when the parse fails
*/
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
  MateParserANSIARGDECL              /* Extra arguments (if any) */
){
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->idx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
#line 188 "./mate_grammar.lemon"

	configuration_error(mc,"Parse Error");

#line 3109 "mate_grammar.c"
}

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser _U_,       /* The parser */
  int yymajor _U_,               /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
  MateParserANSIARGDECL _U_           /* Extra arguments (if any) */
){
#define TOKEN (yyminor.yy0)
#line 184 "./mate_grammar.lemon"

	configuration_error(mc,"Syntax Error before %s",yyminor);

#line 3126 "mate_grammar.c"
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
  MateParserANSIARGDECL _U_          /* Extra arguments (if any) */
){
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->idx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "MateParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void MateParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  MateParserTOKENTYPE yyminor       /* The value for the token */
  MateParserANSIARGDECL
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->idx<0 ){
    if( yymajor==0 ) return;
    yypParser->idx = 0;
    yypParser->errcnt = -1;
    yypParser->top = &yypParser->stack[0];
    yypParser->top->stateno = 0;
    yypParser->top->major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_parser_action(yypParser,yymajor);
    if( yyact<YYNSTATE ){
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->errcnt--;
      if( yyendofinput && yypParser->idx>=0 ){
        yymajor = 0;
      }else{
        yymajor = YYNOCODE;
      }
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE MateParserARGDECL);
    }else if( yyact == YY_ERROR_ACTION ){
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->errcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion MateParserARGDECL);
      }
      if( yypParser->top->major==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->idx >= 0 &&
          yypParser->top->major != YYERRORSYMBOL &&
          (yyact = yy_find_parser_action(yypParser,YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->idx < 0 || yymajor==0 ){
          yy_destructor(yymajor,&yyminorunion);
          yy_parse_failed(yypParser MateParserARGDECL);
          yymajor = YYNOCODE;
        }else if( yypParser->top->major!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->errcnt = 3;
      yyerrorhit = 1;
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->errcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion MateParserARGDECL);
      }
      yypParser->errcnt = 3;
      yy_destructor(yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser MateParserARGDECL);
      }
      yymajor = YYNOCODE;
#endif
    }else{
      yy_accept(yypParser MateParserARGDECL);
      yymajor = YYNOCODE;
    }
  }while( yymajor!=YYNOCODE && yypParser->idx>=0 );
  return;
}
